"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = autoBind;

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

/* eslint-disable @typescript-eslint/ban-types */

/* eslint-disable @typescript-eslint/no-explicit-any */
var defineProperty = Object.defineProperty,
    getOwnPropertyDescriptor = Object.getOwnPropertyDescriptor,
    getOwnPropertyNames = Object.getOwnPropertyNames,
    getOwnPropertySymbols = Object.getOwnPropertySymbols,
    getPrototypeOf = Object.getPrototypeOf;
var mapStore;

/**
 *
 * @param fn
 * @param context
 * @returns {(function(): *)|{new(...args: any[]): any} | ((...args: any[]) => any) | OmitThisParameter<{bind}|*> | {bind} | * | {new(...args: any[]): any} | ((...args: any[]) => any)}
 */
function bind(fn, context) {
  if (fn.bind) {
    return fn.bind(context);
  } else {
    return function __autobind__() {
      /* eslint-disable prefer-rest-params */
      return fn.apply(context, arguments);
    };
  }
}
/**
 *
 * @param obj
 * @param fn
 * @returns {*}
 */


function getBoundSuper(obj, fn) {
  if (typeof WeakMap === 'undefined') {
    throw new Error("Using @autobind on ".concat(fn.name, "() requires WeakMap support due to its use of super.").concat(fn.name, "()\n      See https://github.com/jayphelps/core-decorators.js/issues/20"));
  }

  if (!mapStore) {
    mapStore = new WeakMap();
  }

  if (mapStore.has(obj) === false) {
    mapStore.set(obj, new WeakMap());
  }

  var superStore = mapStore.get(obj);

  if (superStore.has(fn) === false) {
    superStore.set(fn, bind(fn, obj));
  }

  return superStore.get(fn);
}

var getOwnKeys = getOwnPropertySymbols ? function (object) {
  return [].concat((0, _toConsumableArray2.default)(getOwnPropertyNames(object)), (0, _toConsumableArray2.default)(getOwnPropertySymbols(object)));
} : getOwnPropertyNames;
/**
 * 得到自身的描述信息
 * @param obj
 */

function getOwnPropertyDescriptors(obj) {
  var descriptors = {};
  getOwnKeys(obj).forEach(function (key) {
    return descriptors[key] = getOwnPropertyDescriptor(obj, key);
  });
  return descriptors;
}
/**
 *
 * @param key
 * @returns {function(*=): *}
 */


function createDefaultSetter(key) {
  return function set(newValue) {
    Object.defineProperty(this, key, {
      configurable: true,
      writable: true,
      // IS enumerable when reassigned by the outside word
      enumerable: true,
      value: newValue
    });
    return newValue;
  };
}
/**
 *重新定个方法中的this
 * @param target class
 * @param key class中方法
 * @param desc 描述信息
 * @returns {{set: (function(*=): *), enumerable: *, get(): (*|*|*|*), configurable: *}|(function(): *)|*}
 */


function autoBindMethod(target, key, desc) {
  var fn = desc.value,
      configurable = desc.configurable,
      enumerable = desc.enumerable;

  if (typeof fn !== 'function') {
    throw new SyntaxError("@autobind can only be used on functions, not: ".concat(fn));
  }

  var constructor = target.constructor;
  return {
    configurable: configurable,
    enumerable: enumerable,
    get: function get() {
      // Class.prototype.key lookup
      // Someone accesses the property directly on the prototype on which it is
      // actually defined on, i.e. Class.prototype.hasOwnProperty(key)
      if (this === target) {
        return fn;
      } // Class.prototype.key lookup
      // Someone accesses the property directly on a prototype but it was found
      // up the chain, not defined directly on it
      // i.e. Class.prototype.hasOwnProperty(key) == false && key in Class.prototype


      if (this.constructor !== constructor && getPrototypeOf(this).constructor === constructor) {
        return fn;
      }
      /**调用super.sameMethod()的自动绑定方法，它也是自动绑定的，依此类推。**/


      if (this.constructor !== constructor && key in this.constructor.prototype) {
        return getBoundSuper(this, fn);
      }

      var boundFn = bind(fn, this);
      defineProperty(this, key, {
        configurable: true,
        writable: true,
        // NOT enumerable when it's a bound method
        enumerable: false,
        value: boundFn
      });
      return boundFn;
    },
    set: createDefaultSetter(key)
  };
}
/**
 * 自动绑定类
 * @param klass
 */


function autoBindClass(klass) {
  /**得到原型上每个方法的描述信息**/
  var descriptors = getOwnPropertyDescriptors(klass.prototype);
  /**方法名称**/

  var keys = getOwnKeys(descriptors);

  for (var i = 0, l = keys.length; i < l; i++) {
    /**每个方法名称**/
    var key = keys[i];
    /**方法对应的描述信息**/

    var desc = descriptors[key];

    if (typeof desc.value !== 'function' || key === 'constructor') {
      continue;
    }
    /**给每个方法重新绑定this**/


    defineProperty(klass.prototype, key, autoBindMethod(klass.prototype, key, desc));
  }
}
/**
 * react类中自动绑定this
 * @param args
 * @returns {(function(): (void|{enumerable, get, configurable}))|void|{enumerable, get, configurable}}
 */


function autoBind() {
  for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }

  if (args.length === 1) {
    return autoBindClass(args[0]);
  } else {
    var target = args[0],
        key = args[1],
        desc = args[2];
    return autoBindMethod(target, key, desc);
  }
}