"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = domresize;

/**
 * 监测一个div元素的大小变化（类似原生resize）
 * @param el 变化元素
 * @param cb 变化后的回调
 */
function domresize(el, cb) {
  var _el$lastChild, _el$lastChild$getAttr;

  var prevIframe = (_el$lastChild = el.lastChild) === null || _el$lastChild === void 0 ? void 0 : (_el$lastChild$getAttr = _el$lastChild.getAttribute('class')) === null || _el$lastChild$getAttr === void 0 ? void 0 : _el$lastChild$getAttr.includes('size-watch');

  if (prevIframe) {
    return; // el.removeChild(prevIframe);
  } // 创建iframe标签，设置样式并插入到被监听元素中


  var iframe = document.createElement('iframe');
  iframe.setAttribute('class', 'size-watch');
  el.appendChild(iframe); // 记录元素当前宽高

  var oldWidth = el.offsetWidth;
  var oldHeight = el.offsetHeight; // iframe 大小变化时的回调函数

  var sizeChange = function sizeChange() {
    // 记录元素变化后的宽高
    var width = el.offsetWidth;
    var height = el.offsetHeight; // 不一致时触发回调函数 cb，并更新元素当前宽高

    if (width !== oldWidth || height !== oldHeight) {
      cb({
        width: width,
        height: height
      }, {
        width: oldWidth,
        height: oldHeight
      });
      oldWidth = width;
      oldHeight = height;
    }
  }; // 设置定时器用于节流


  var timer = null; // 将 sizeChange 函数挂载到 iframe 的resize回调中

  iframe.contentWindow.onresize = function () {
    clearTimeout(timer);
    timer = setTimeout(sizeChange, 100);
  };
}