"use strict";

var _typeof = require("@babel/runtime/helpers/typeof");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.UUID = UUID;
exports.addEvent = addEvent;
exports.classList = classList;
exports.classType = classType;
exports.combineRef = combineRef;
exports.debounce = debounce;
exports.deepClone = deepClone;
exports.getPrefixCls = getPrefixCls;
exports.isDisplayNone = isDisplayNone;
exports.isExist = isExist;
exports.isIE = void 0;
exports.isIE9 = isIE9;
exports.once = once;
exports.removeEvent = removeEvent;
exports.setPrefix = setPrefix;
exports.throttle = throttle;

var React = _interopRequireWildcard(require("react"));

var _reactDom = require("react-dom");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 *
 * @param el
 * @param event
 * @param handler
 * @param useCapture
 */
function addEvent(el, event, handler) {
  var useCapture = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;

  if (!el) {
    return;
  }

  if (el.addEventListener) {
    el.addEventListener(event, handler, useCapture);
  } else if (el.attachEvent) {
    el.attachEvent("on".concat(event), handler);
  } else {
    el["on".concat(event)] = handler;
  }
}
/**
 *
 * @param el
 * @param event
 * @param handler
 * @param useCapture
 */


function removeEvent(el, event, handler) {
  var useCapture = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;

  if (!el) {
    return;
  }

  if (el.removeEventListener) {
    el.removeEventListener(event, handler, useCapture);
  } else if (el.detachEvent) {
    el.detachEvent("on".concat(event), handler);
  } else {
    el["on".concat(event)] = null;
  }
}
/**
 * 根据浏览器自动给str设置前缀
 * @param str
 */


function setPrefix() {
  var str = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'transform';
  var style = window.document.documentElement.style;
  var prefixes = ['moz', 'webkit', 'o', 'ms'];

  if (str in style) {
    return str;
  }

  var firstUpper = str.charAt(0).toUpperCase() + str.slice(1);

  for (var i = 0; i < prefixes.length; i++) {
    var mix = prefixes[i] + firstUpper;

    if (mix in style) {
      return mix;
    }
  }

  return str;
}
/**
 * 节流
 * @param fn
 * @param delay
 */


function throttle(fn) {
  var _this = this;

  var delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 500;
  var flag = true;
  return function () {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    if (!flag) {
      return;
    }

    flag = false;
    setTimeout(function () {
      fn.apply(_this, args);
      flag = true;
    }, delay);
  };
}
/**
 * 防抖函数
 * @param fn
 * @param delay
 */


function debounce(fn, delay) {
  var _this2 = this;

  // 定时器，用来 setTimeout
  var timer; // 返回一个函数，这个函数会在一个时间区间结束后的 delay 毫秒时执行 fn 函数

  return function () {
    for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }

    // 每次这个返回的函数被调用，就清除定时器，以保证不执行 fn
    clearTimeout(timer); // 当返回的函数被最后一次调用后（也就是用户停止了某个连续的操作），
    // 再过 delay 毫秒就执行 fn

    timer = setTimeout(function () {
      fn.apply(_this2, args);
    }, delay);
  };
}
/**
 *
 * @param suffixCls
 * @param customPrefixCls
 */


function getPrefixCls(suffixCls, customPrefixCls) {
  if (customPrefixCls) {
    return customPrefixCls;
  }

  return suffixCls ? "rd-".concat(suffixCls) : 'rd';
}
/**
 * 类似于dom的classList
 *
 */


function classList(dom) {
  var _dom$className;

  var _dom = dom;
  var classes = (dom === null || dom === void 0 ? void 0 : (_dom$className = dom.className) === null || _dom$className === void 0 ? void 0 : _dom$className.trim().split(/\s+/g)) || [];
  return {
    add: function add() {
      for (var _len3 = arguments.length, params = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
        params[_key3] = arguments[_key3];
      }

      params.forEach(function () {
        var param = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
        var index = classes.indexOf(param);
        /**确保没有该类**/

        if (index === -1) {
          classes.push(params);
        }
      });
      classes = classes.flat();
      _dom && (_dom.className = classes.join(' ').trim());
    },
    remove: function remove() {
      for (var _len4 = arguments.length, params = new Array(_len4), _key4 = 0; _key4 < _len4; _key4++) {
        params[_key4] = arguments[_key4];
      }

      params.forEach(function () {
        var param = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
        var index = classes.indexOf(param);

        if (index !== -1) {
          classes.splice(index, 1);
        }
      });

      if (_dom && classes.length === 0) {
        return _dom.removeAttribute('class');
      }

      _dom && (_dom.className = classes.join(' ').trim());
    },
    toggle: function toggle(token, force) {
      var index = classes.indexOf(token);

      if (index === -1) {
        classes.push(token);
      } else if (!force) {
        classes.splice(index, 1);
      }

      if (_dom && classes.length === 0) {
        _dom.removeAttribute('class');

        return true;
      }

      _dom && (_dom.className = classes.join(' ').trim());
      return true;
    },
    contains: function contains(token) {
      return !!classes.find(function (item) {
        return token === item;
      });
    }
  };
}
/**
 * 克隆
 * @returns {Array}
 * @param origin
 * @param target
 */


function deepClone(obj) {
  // 先检测是不是数组和Object
  // let isMap = Object.prototype.toString.call(obj) === '[object Map];
  // let isSet = Object.prototype.toString.call(obj) === '[object Set];
  // let isArr = Object.prototype.toString.call(obj) === '[object Array]';
  var isArr = Array.isArray(obj);
  var isJson = Object.prototype.toString.call(obj) === '[object Object]';

  if (isArr) {
    // 克隆数组
    var newObj = [];

    for (var i = 0; i < obj.length; i++) {
      newObj[i] = deepClone(obj[i]);
    }

    return newObj;
  } else if (isJson) {
    // 克隆Object
    var _newObj = {};

    for (var _i in obj) {
      _newObj[_i] = deepClone(obj[_i]);
    }

    return _newObj;
  } // 不是引用类型直接返回


  return obj;
}
/**
 * 判断是否是ie9环境
 */


function isIE9() {
  return navigator.appName === "Microsoft Internet Explorer" && navigator.appVersion.split(";")[1].replace(/[ ]/g, "") === "MSIE9.0";
}
/**
 * 取出arg类型的类型 比如 1 会得到'number' '1'会得到String
 * @param arg
 */


function classType(arg) {
  return Object.prototype.toString.call(arg).match(/^\[object ([^\]]*)]$/)[1];
}
/**
 * 判断元素是否display:none
 * @param node
 */


function isDisplayNone(node) {
  var _node$getBoundingClie = node.getBoundingClientRect(),
      width = _node$getBoundingClie.width,
      height = _node$getBoundingClie.height;

  return !(width === 0 && height === 0 && node.offsetWidth === 0 && node.offsetHeight === 0);
}
/**
 * 只执行一次fn
 * @param fn
 * @param context
 */


function once(fn, context) {
  var result;
  return function () {
    if (fn) {
      for (var _len5 = arguments.length, params = new Array(_len5), _key5 = 0; _key5 < _len5; _key5++) {
        params[_key5] = arguments[_key5];
      }

      result = fn.apply(context || this, params);
      fn = null;
    }

    return result;
  };
}
/**
 * 随机生成UUID
 */


function UUID() {
  return 'uuid-xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
    var r = Math.random() * 16 | 0,
        v = c === 'x' ? r : r & 0x3 | 0x8;
    return v.toString(16);
  });
}
/**
 * 合并函数形式的ref和对象形式的ref
 * @param props
 * @param forceDom 是否将结果统一转成原始Dom
 */


function combineRef(props) {
  var forceDom = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  var ref = props.forwardRef || /*#__PURE__*/React.createRef();

  if (ref instanceof Function) {
    var originFn = ref;
    var current;

    ref = function ref(_ref) {
      originFn.bind(this)(_ref);
      current = _ref;
    };

    Object.defineProperty(ref, 'current', {
      get: function get() {
        return forceDom ? (0, _reactDom.findDOMNode)(current) : current;
      }
    });
  } else if (forceDom) {
    var objRef = ref;
    ref = {
      current: null
    };
    Object.defineProperty(ref, 'current', {
      get: function get() {
        return (0, _reactDom.findDOMNode)(objRef.current);
      },
      set: function set(v) {
        objRef.current = v;
      }
    });
  }

  return ref;
}
/**
 * 判断是否存在
 * @param value
 */


function isExist(value) {
  if (value === null || value === undefined || value === false) {
    return false;
  } else if (typeof value === 'number') {
    return !isNaN(value);
  } else {
    return true;
  }
}
/**判断是否是ie环境**/


var isIE = navigator.userAgent.toLowerCase().indexOf('trident') > -1;
exports.isIE = isIE;