"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ascii = ascii;
exports.byteLen = byteLen;
exports.date = date;
exports.domain = domain;
exports.email = email;
exports.hex = hex;
exports.ip = ip;
exports.mac = mac;
exports.mask = mask;
exports.numRange = numRange;
exports.serverName = serverName;
exports.ssid = ssid;
exports.ssidPwd = ssidPwd;
exports.url = url;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _locale = _interopRequireDefault(require("../../package/locale"));

var _warning = _interopRequireDefault(require("../warning"));

var _types = require("../types");

var _react = _interopRequireDefault(require("react"));

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

var FormatType = (0, _types.tuple)('-', ':', 'empty');
var Formatter = _locale.default.Formatter;
var IPRegExp = /^([1-9]|[1-9]\d|(1[013456789]\d|12[012345689])|2[0-1]\d|22[0-3])\.(([0-9]|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])\.){2}([0-9]|[1-9]\d|1\d\d|2[0-4]\d|25[0-5])$/;
/**校验空字符串时，返回true */

function _requiredValue(value, callback, validate) {
  if (value === '') {
    callback();
    return true;
  } else {
    return validate && validate();
  }
}
/**ip的某一位 */


function _lastIpRange(lastIp, end) {
  if (Object.prototype.toString.call(end) === '[object RegExp]') {
    if (end.test(lastIp)) {
      return true;
    } else {
      return false;
    }
  } else {
    var numLastIp = Number(lastIp);
    var range = end.toString().split('-');

    if (!range[1]) {
      range[1] = range[0];
    }

    if (numLastIp < Number(range[0]) || numLastIp > Number(range[1])) {
      return false;
    }
  }

  return true;
}
/**
 *
 * @param mac
 * @param lower： 是否转换大小写
 */


function _toNormalMac(mac, lower) {
  //000000000000 or 000000000000; or 000000000000-000000000002
  var macStr = mac.toUpperCase().replace(/[:\-]/g, '');

  if (lower) {
    macStr = mac.toLowerCase().replace(/[:\-]/g, '');
  }

  var arr = macStr.match(/[0-9a-fA-F]{1,2}\;?~?/g);

  if (arr) {
    return arr.join(':').replace(/\;\:/g, ';').replace(/~\:/g, '~');
  } else {
    return mac;
  }
}
/**
 * 获取字节长度
 * @param value
 */


function _getByteLength(value) {
  if (typeof Blob === 'undefined') {
    return unescape(encodeURIComponent(value)).length;
  } else {
    var blob = new Blob([value]);
    return blob.size;
  }
}
/**判断字节长度 */


function _byteLength(rule, value) {
  var message = rule.message,
      _rule$params = rule.params,
      params = _rule$params === void 0 ? {} : _rule$params;
  var range = params.range;
  var validator = {
    res: true,
    message: undefined
  };

  if (range && range.length === 2) {
    var min = range[0];
    var max = range[1];

    var len = _getByteLength(value);

    if (len < min || len > max) {
      validator.message = message || /*#__PURE__*/_react.default.createElement(Formatter, {
        path: "rd.validator.byteRange",
        options: {
          min: min,
          max: max
        }
      });
      validator.res = false;
    }
  } else {
    (0, _warning.default)(false, 'validator.byteLen', 'byteLen校验方法，params.range = [min, max]参数必填');
  }

  return validator;
}
/**
 * ascii校验
 * @param rule
 * @param value
 */


function _ascii(rule, value) {
  var message = rule.message,
      _rule$params2 = rule.params,
      params = _rule$params2 === void 0 ? {} : _rule$params2;
  var _params$range = params.range,
      range = _params$range === void 0 ? [] : _params$range;

  var msg = message || /*#__PURE__*/_react.default.createElement(Formatter, {
    path: "rd.validator.ascii"
  });

  var validator = {
    res: true,
    message: undefined
  };

  for (var i = 0, len = value.length; i < len; i++) {
    var code = value.charCodeAt(i);

    if (65248 < code || 12288 === code) {
      //全角字符
      return {
        res: false,
        message: msg
      };
    }
  }

  if (!/^[ -~]+$/g.test(value)) {
    return {
      res: false,
      message: msg
    };
  }

  if (range.length === 2) {
    var min = range[0];
    var max = range[1];

    if (value.length < min || value.length > max) {
      return {
        res: false,
        message: message || /*#__PURE__*/_react.default.createElement(Formatter, {
          path: "rd.validator.asciiRange",
          options: {
            min: min,
            max: max
          }
        })
      };
    }
  }

  return validator;
}
/**
 * 十六进制校验
 * @param rule
 * @param value
 */


function _hex(rule, value) {
  var message = rule.message,
      _rule$params3 = rule.params,
      params = _rule$params3 === void 0 ? {} : _rule$params3;
  var _params$range2 = params.range,
      range = _params$range2 === void 0 ? [] : _params$range2;

  var msg = message || /*#__PURE__*/_react.default.createElement(Formatter, {
    path: "rd.validator.hex"
  });

  var validator = {
    res: true,
    message: undefined
  };

  if (!/^[0-9a-fA-F]{1,}$/.test(value)) {
    return {
      res: false,
      message: msg
    };
  }

  if (range.length === 2) {
    var min = range[0];
    var max = range[1];

    if (value.length < min || value.length > max) {
      return {
        res: false,
        message: message || /*#__PURE__*/_react.default.createElement(Formatter, {
          path: "rd.validator.hexRange",
          options: {
            min: min,
            max: max
          }
        })
      };
    }
  }

  return validator;
}
/**
 * 数值大小范围
 * @param {Rule} rule
 * @param {string | number} value
 * @returns {Validator}
 */


function _numRange(rule, value) {
  var message = rule.message,
      _rule$params4 = rule.params,
      params = _rule$params4 === void 0 ? {} : _rule$params4;
  var _params$range3 = params.range,
      range = _params$range3 === void 0 ? [] : _params$range3;
  var validator = {
    res: true,
    message: undefined
  };

  if (range.length === 2) {
    var min = Number(range[0]);
    var max = Number(range[1]);

    if (!/^([1-9]\d*|0)$/.test(value + '')) {
      return {
        res: false,
        message: message || /*#__PURE__*/_react.default.createElement(Formatter, {
          path: "rd.validator.onlyNumber",
          options: {
            min: min,
            max: max
          }
        })
      };
    }

    if (Number(value) < min || Number(value) > max) {
      return {
        res: false,
        message: message || /*#__PURE__*/_react.default.createElement(Formatter, {
          path: "rd.validator.numRange",
          options: {
            min: min,
            max: max
          }
        })
      };
    }
  }

  return validator;
}
/**
 * IP地址校验
 * @param rule { message: string; params?: {start: string|number|RegExp, end: string|number|RegExp }
 *  end 最后一位匹配内容；字符串只能为以下两种写法：0 or 0-255
 *  start 暂时未使用
 * @param value
 * @param callback
 */


function ip(rule, value, callback) {
  var message = rule.message,
      _rule$params5 = rule.params,
      params = _rule$params5 === void 0 ? {} : _rule$params5;
  return _requiredValue(value, callback, function () {
    var msg = /*#__PURE__*/_react.default.createElement(Formatter, {
      path: "rd.validator.ip"
    });

    if (IPRegExp.test(value)) {
      var ips = value.split('.');

      if (params.end !== void 0) {
        var lastIp = ips[3];

        if (_lastIpRange(lastIp, params.end)) {
          callback();
          return true;
        }
      } else {
        callback();
        return true;
      }
    } else {
      var _ips = value.split('.');

      if (_ips[0] && /\d+/.test(_ips[0])) {
        var startIp = Number(_ips[0]);

        if (startIp > 223) {
          msg = /*#__PURE__*/_react.default.createElement(Formatter, {
            path: "rd.validator.ip223",
            options: {
              start: _ips[0]
            }
          });
        } else if (startIp === 127) {
          msg = /*#__PURE__*/_react.default.createElement(Formatter, {
            path: "rd.validator.ipStart127"
          });
        }
      }
    }

    callback(message || msg);
    return false;
  });
}
/**
 * 子网掩码校验
 * @param rule { message: string; params?: {start: string|number|RegExp, end: string|number|RegExp }} 若不传params，则最后一位默认为：0 - 254
 *  end: 最后一位匹配内容；字符串只能为以下两种写法：0 or 0-255
 *  start: 暂时未使用
 * @param value
 * @param callback
 */


function mask(rule, value, callback) {
  var message = rule.message;
  var _rule$params6 = rule.params,
      params = _rule$params6 === void 0 ? {} : _rule$params6;
  return _requiredValue(value, callback, function () {
    var reg = /^(254|252|248|240|224|192|128)\.0\.0\.0$|^(255\.(254|252|248|240|224|192|128|0)\.0\.0)$|^(255\.255\.(254|252|248|240|224|192|128|0)\.0)$|^(255\.255\.255\.(255|254|252|248|240|224|192|128|0))$/;

    if (reg.test(value)) {
      var lastIp = value.split('.')[3];

      if (params.end !== void 0) {} else {
        params = _objectSpread(_objectSpread({}, params), {}, {
          end: '0-254'
        });
      }

      if (_lastIpRange(lastIp, params.end)) {
        if (params.start !== void 0) {
          var firstIp = value.split('.')[0];

          if (_lastIpRange(firstIp, params.start)) {
            callback();
            return true;
          }
        } else {
          callback();
          return true;
        }
      }
    }

    callback(message || /*#__PURE__*/_react.default.createElement(Formatter, {
      path: "rd.validator.mask"
    }));
    return false;
  });
}
/**
 * 校验mac地址
 * @param rule { message: string; params?: {params: { format: [':','-', 'empty'], special: ['00:00:00:00:00:00','']}} 若不传params，则默认支持:格式，默认全0 mac为false
 *  format: 支持格式为：冒号，-，和纯字符(empty)的数组集合
 *  special：表示特殊支持mac
 * @param value
 * @param callback
 */


function mac(rule, value, callback) {
  var message = rule.message,
      _rule$params7 = rule.params,
      params = _rule$params7 === void 0 ? {} : _rule$params7;
  var _params$format = params.format,
      format = _params$format === void 0 ? ':' : _params$format,
      _params$special = params.special,
      special = _params$special === void 0 ? [] : _params$special;

  var msg = message || /*#__PURE__*/_react.default.createElement(Formatter, {
    path: "rd.validator.mac"
  });

  return _requiredValue(value, callback, function () {
    var reg = {
      ':': /^([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}$/,
      '-': /^([0-9a-fA-F]{2}-){5}[0-9a-fA-F]{2}$/,
      'empty': /^([0-9a-fA-F]){10}[0-9a-fA-F]{2}$/
    }; //只要支持一种format即为真

    var res = false;

    if (typeof format === 'string') {
      res = reg[format] && reg[format].test(value);
    } else {
      for (var i = 0, len = format.length; i < len; i++) {
        var fmt = format[i];

        if (reg[fmt].test(value)) {
          res = true;
          break;
        }
      }
    }

    if (!res) {
      callback(msg);
      return false;
    }

    var normalMac = _toNormalMac(value);

    var subMac = normalMac.split(':')[0];

    if (subMac.charAt(1) && parseInt(subMac.charAt(1), 16) % 2 !== 0) {
      callback(msg);
      return false;
    } //暂时看来只有全0为特殊处理


    if (special.find(function (item) {
      return _toNormalMac(item) === normalMac;
    })) {} else if (normalMac === '00:00:00:00:00:00') {
      callback(msg);
      return false;
    }

    callback();
    return true;
  });
}
/**
 * 校验ssid
 * @param rule { message: string; params?: {range, excludeRegExp} 若不传params，则默认支持:格式，默认全0 mac为false
 *  range: 长度范围
 *  excludeRegExp: 特殊匹配，不支持的内容 ？是否需要这个字段？
 * @param value
 * @param callback
 */


function ssid(rule, value, callback) {
  var message = rule.message,
      _rule$params8 = rule.params,
      params = _rule$params8 === void 0 ? {} : _rule$params8;
  var excludeRegExp = params.excludeRegExp;
  return _requiredValue(value, callback, function () {
    var validator = _byteLength(rule, value);

    if (validator.res) {
      if (excludeRegExp && Object.prototype.toString.call(excludeRegExp) === '[object RegExp]') {
        if (excludeRegExp.test(value)) {
          callback(message || /*#__PURE__*/_react.default.createElement(Formatter, {
            path: "rd.validator.ssid"
          }));
          return false;
        }
      }
    }

    callback(validator.message);
    return validator.res;
  });
}
/**
 * 校验wifi密码
 * @param rule { message: string; params?: {}
 * @param value
 * @param callback
 */


function ssidPwd(rule, value, callback) {
  return _requiredValue(value, callback, function () {
    var message = rule.message;

    var validator = _hex(_objectSpread(_objectSpread({}, rule), {}, {
      params: {
        range: [8, 64]
      }
    }), value);

    var validatorAscii = _ascii(_objectSpread(_objectSpread({}, rule), {}, {
      params: {
        range: [8, 63]
      }
    }), value);

    if (validator.res || validatorAscii.res) {
      callback();
      return true;
    } else {
      callback(message || /*#__PURE__*/_react.default.createElement(Formatter, {
        path: "rd.validator.ssidPwd"
      }));
      return false;
    }
  });
}
/**
 * 校验ascii
 * @param rule { message: string; params?: {range}
 *  range: 长度范围
 * @param value
 * @param callback
 */


function ascii(rule, value, callback) {
  return _requiredValue(value, callback, function () {
    var validator = _ascii(rule, value);

    callback(validator.message);
    return validator.res;
  });
}
/**
 * 校验hex
 * @param rule { message: string; params?: {params: {range }}
 *  range: 长度范围
 * @param value
 * @param callback
 */


function hex(rule, value, callback) {
  return _requiredValue(value, callback, function () {
    var validator = _hex(rule, value);

    callback(validator.message);
    return validator.res;
  });
}
/**
 * 校验字符字节长度
 * @param rule { message: string; params?: { range: []}}
 * @param value
 * @param callback
 */


function byteLen(rule, value, callback) {
  return _requiredValue(value, callback, function () {
    var validator = _byteLength(rule, value);

    callback(validator.message);
    return validator.res;
  });
}
/**
 * 校验值的范围
 *
 * @export
 * @param {Rule} rule { message: string; params?: { range: [min, max]}}
 * @param {string} value
 * @param {(error?: string) => void} callback
 * @returns {boolean}
 */


function numRange(rule, value, callback) {
  return _requiredValue(value, callback, function () {
    var validator = _numRange(rule, value);

    callback(validator.message);
    return validator.res;
  });
}
/**
 * 邮箱地址校验
 * @param rule { message: string; }
 * @param value
 * @param callback
 */


function email(rule, value, callback) {
  return _requiredValue(value, callback, function () {
    var message = rule.message;

    var msg = message || /*#__PURE__*/_react.default.createElement(Formatter, {
      path: "rd.validator.email"
    });

    if (value.indexOf('@') <= 0) {
      callback(msg);
      return false;
    }

    var emailFlag = value.split('@');

    if (emailFlag.length !== 2 || emailFlag[0].length === 0 || emailFlag[1].length === 0 || value.length > 64) {
      callback(msg);
      return false;
    }

    var domainFlag = emailFlag[1].split('.');

    if (domainFlag.length < 2) {
      callback(msg);
      return false;
    } else {
      var pattern = /^[a-zA-Z0-9.!#$%&*+\/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$/;

      if (pattern.test(value)) {
        callback();
        return true;
      } else {
        callback(msg);
        return false;
      }
    }
  });
}
/**
 * 域名校验
 * @export
 * @param {Rule} rule { message: string, params: { special: Array<string>; includeIp: boolean } }
 *  includeIp:表示域名是否包含ip，true：包含IP，false：不包含IP，默认为 true
 *  special: 表示允许的特殊数据
 * @param {string} value
 * @param {(error?: string) => void} callback
 * @returns {boolean}
 */


function domain(rule, value, callback) {
  var _domainOnly = function _domainOnly(message, value) {
    if (!/^[a-zA-Z0-9][_\-a-zA-Z0-9]{0,62}(\.[a-zA-Z0-9][_\-a-zA-Z0-9]{0,62})+$/.test(value)) {
      return {
        res: false,
        message: message || /*#__PURE__*/_react.default.createElement(Formatter, {
          path: "rd.validator.domain"
        })
      };
    }

    if (value.length > 253) {
      return {
        res: false,
        message: message || /*#__PURE__*/_react.default.createElement(Formatter, {
          path: "rd.validator.domainRange",
          options: {
            min: 1,
            max: 253
          }
        })
      };
    }

    return {
      res: true,
      message: undefined
    };
  };

  return _requiredValue(value, callback, function () {
    var message = rule.message,
        _rule$params9 = rule.params,
        params = _rule$params9 === void 0 ? {} : _rule$params9;
    var _params$special2 = params.special,
        special = _params$special2 === void 0 ? [] : _params$special2,
        _params$includeIp = params.includeIp,
        includeIp = _params$includeIp === void 0 ? true : _params$includeIp;

    var msg = message || /*#__PURE__*/_react.default.createElement(Formatter, {
      path: "rd.validator.domain"
    });
    /**以.数字结尾的认为是IP地址 */


    var isIp = /\.[0-9]{1,}$/.test(value);

    if (special.find(function (item) {
      return item === value;
    })) {
      callback();
      return true;
    }

    if (includeIp && isIp) {
      //按照IP地址来校验
      if (IPRegExp.test(value)) {
        callback();
        return true;
      }

      callback(msg);
      return false;
    } else if (!includeIp && isIp) {
      //不包含IP，输入为IP地址，直接返回错误
      callback(msg);
      return false;
    }

    var validator = _domainOnly(message, value);

    callback(validator.message);
    return validator.res;
  });
}
/**
 * URL地址完整校验
 * @export
 * @param {Rule} rule { message: string, params: { protocol: string, protocolRequired: boolean } }
 * protocol: 支持的協議，http,https or both
 * protocolRequired: 協議是否必填，默認為false
 * @param {string} value
 * @param {(error?: string) => void} callback
 * @returns {boolean}
 */


function url(rule, value, callback) {
  var urlProtocol = {
    both: {
      required: '((ht)tps?):\\/\\/',
      unRequired: '(((ht)tps?):\\/\\/)?'
    },
    http: {
      required: 'http:\\/\\/',
      unRequired: '(http:\\/\\/)?'
    },
    https: {
      required: 'https:\\/\\/',
      unRequired: '(https:\\/\\/)?'
    }
  };
  return _requiredValue(value, callback, function () {
    var message = rule.message,
        _rule$params10 = rule.params,
        params = _rule$params10 === void 0 ? {} : _rule$params10;

    var msg = message || /*#__PURE__*/_react.default.createElement(Formatter, {
      path: "rd.validator.url"
    });

    var _params$protocol = params.protocol,
        protocol = _params$protocol === void 0 ? 'both' : _params$protocol,
        _params$protocolRequi = params.protocolRequired,
        protocolRequired = _params$protocolRequi === void 0 ? false : _params$protocolRequi;
    var urlRegExpMsg = "^".concat(urlProtocol[protocol][protocolRequired ? 'required' : 'unRequired'], "[a-z0-9][_\\-a-z0-9]{0,62}(\\.[a-z0-9][_\\-a-z0-9]{0,62})+(\\:\\d+)?((\\/|\\?)[\\w.\\S]{0,})?$");
    var urlRegExp = new RegExp(urlRegExpMsg, 'i');
    var hostName = value.replace(/^(ht)tps?:\/\/|((\/|\?)[\w.\S]{0,})$/g, '');
    var hostNameLen = hostName.length;
    var validator = {
      res: true,
      message: undefined
    };

    if (hostName.indexOf(':') > -1) {
      var port = parseInt(hostName.split(':')[1], 10);
      hostNameLen = hostName.split(':')[0].length;
      validator = _numRange({
        message: /*#__PURE__*/_react.default.createElement(Formatter, {
          path: "rd.validator.portRange",
          options: {
            min: 1,
            max: 65535
          }
        }),
        params: {
          range: [1, 65535]
        }
      }, port);

      if (!validator.res) {
        callback(validator.message);
        return false;
      }
    }

    if (hostNameLen <= 0 || hostNameLen > 253) {
      callback( /*#__PURE__*/_react.default.createElement(Formatter, {
        path: "rd.validator.domainRange",
        options: {
          min: 1,
          max: 253
        }
      }));
      return false;
    }

    if (value.length > 512) {
      callback( /*#__PURE__*/_react.default.createElement(Formatter, {
        path: "rd.validator.maxChar",
        options: {
          max: 512
        }
      }));
      return false;
    }

    if (!urlRegExp.test(value)) {
      callback(msg);
      return false;
    }

    callback();
    return true;
  });
}
/**
 * 服务名和服务器名
 *
 * @export
 * @param {Rule} rule
 * @param {string} value
 * @param {(error?: string) => void} callback
 * @returns {boolean}
 */


function serverName(rule, value, callback) {
  return _requiredValue(value, callback, function () {
    var message = rule.message;

    if (!/^[0-9a-zA-Z_\-\:@+\.]+$/.test(value)) {
      callback(message || /*#__PURE__*/_react.default.createElement(Formatter, {
        path: "rd.validator.serverName"
      }));
      return false;
    }

    if (value.length > 32) {
      callback(message || /*#__PURE__*/_react.default.createElement(Formatter, {
        path: "rd.validator.maxChar",
        options: {
          max: 32
        }
      }));
      return false;
    }

    callback();
    return true;
  });
}
/**
 * 日期格式校验
 *
 * @export
 * @param {Rule} rule { message: string, params: { dateFormat: 'yyyy-MM-dd hh:mm:ss'},  }
 * @param {string} value
 * @param {(error?: string) => void} callback
 * @returns {boolean}
 */


function date(rule, value, callback) {
  var validDate = function validDate(year, month, date) {
    if (month === '' || year === '') {
      return true;
    }

    var monthNum = Number(month);
    var maxDay = 30;

    if (monthNum === 2) {
      var yearNum = Number(year);

      if (yearNum % 100 === 0) {
        maxDay = yearNum % 400 === 0 ? 29 : 28;
      } else {
        maxDay = yearNum % 4 === 0 ? 29 : 28;
      }
    } else if (monthNum < 8) {
      if (monthNum % 2 === 1) {
        maxDay = 31;
      }
    } else {
      if (monthNum % 2 === 0) {
        maxDay = 31;
      }
    }

    return Number(date) <= maxDay;
  };

  return _requiredValue(value, callback, function () {
    var message = rule.message,
        _rule$params11 = rule.params,
        params = _rule$params11 === void 0 ? {} : _rule$params11;

    var msg = message || /*#__PURE__*/_react.default.createElement(Formatter, {
      path: "rd.validator.date"
    });

    var _params$dateFormat = params.dateFormat,
        dateFormat = _params$dateFormat === void 0 ? 'yyyy-MM-dd hh:mm:ss' : _params$dateFormat;
    var dateFormats = dateFormat.replace(/yyyy/, '([0-9]{4})').replace(/yy/, '([0-9]{2})');
    dateFormats = dateFormats.replace(/MM/, '((?:0?[1-9])|1[0-2])');
    dateFormats = dateFormats.replace(/dd/, '((?:0?[1-9])|(?:[1-2][0-9])|30|31)');
    dateFormats = dateFormats.replace(/hh/, '(0?[0-9]|1[0-9]|20|21|22|23)');
    dateFormats = dateFormats.replace(/mm/, '(0?[0-9]|(?:[1-5][0-9]))');
    dateFormats = dateFormats.replace(/ss/, '(0?[0-9]|(?:[1-5][0-9]))'); // dateFormat = dateFormat.replace(/MM/, '((?:0[1-9])|1[0-2])').replace(/M/, '((?:[1-9])|1[0-2])');
    // dateFormat = dateFormat.replace(/dd/, '((?:0[1-9])|(?:[1-2][0-9])|30|31)').replace(/d/, '([1-9]|[1-2][0-9]|30|31)');
    // dateFormat = dateFormat.replace(/hh/, '((?:[0-1][0-9])|20|21|22|23)').replace(/h/, '([0-9]|1[0-9]|20|21|22|23)');
    // dateFormat = dateFormat.replace(/mm/, '([0-5][0-9])').replace(/m/, '([0-9]|(?:[1-5][0-9]))');
    // dateFormat = dateFormat.replace(/ss/, '([0-5][0-9])').replace(/s/, '([0-9]|(?:[1-5][0-9]))');

    var reg = new RegExp("^".concat(dateFormats, "$"));
    var matches = value.match(reg); // ["2014-09-30 23:32:32", "2014", "09", "30", "23", "32", "32", index: 0, input: "2014-09-30 23:32:32", groups: undefined]
    //判断年月日，平年，闰年，2月，大小月

    if (matches) {
      //排序MM, dd, yyyy所在位置进行排序，从小到大，最前面的就是matches中的数组匹配中的1开始
      var yyIndex = dateFormat.indexOf('yyyy') >= 0 ? dateFormat.indexOf('yyyy') : dateFormat.indexOf('yy');
      var MMIndex = dateFormat.indexOf('MM');
      var ddIndex = dateFormat.indexOf('dd');
      var hhIndex = dateFormat.indexOf('hh');
      var mmIndex = dateFormat.indexOf('mm');
      var ssIndex = dateFormat.indexOf('ss'); //以上只要能找到，则不可能相同
      //去掉为-1的index
      //排序

      var indexArr = [yyIndex, MMIndex, ddIndex, hhIndex, mmIndex, ssIndex].filter(function (value) {
        return value >= 0;
      }).sort(function (a, b) {
        return a - b;
      });
      var yearIndex = indexArr.findIndex(function (value) {
        return value === yyIndex;
      });
      var monthIndex = indexArr.findIndex(function (value) {
        return value === MMIndex;
      });
      var dateIndex = indexArr.findIndex(function (value) {
        return value === ddIndex;
      });
      var year = yearIndex > -1 ? matches[yearIndex + 1] : '';
      var month = monthIndex > -1 ? matches[monthIndex + 1] : '';

      var _date = dateIndex > -1 ? matches[dateIndex + 1] : '';

      if (_date !== '' && !validDate(year, month, _date)) {
        callback(msg);
        return false;
      }
    } else {
      callback(msg);
      return false;
    }

    callback();
    return true;
  });
}