import * as React from 'react';
declare const StatusType: ["success", "warning", "error", "default"];
export interface BadgeProps {
    /**正常徽标，数字，字符串或者icon */
    count?: React.ReactNode;
    /**小圆点 */
    dot?: boolean;
    /**状态，只针对dot有效 */
    status?: typeof StatusType[number];
    /**针对status，或者是单独dot有效（即无children） */
    text?: React.ReactNode;
    /**0是否还显示徽标 */
    showZero?: boolean;
    /**最大显示数字 */
    maxCount?: number;
    /**徽标的位置位移, [left, top]，距离默认点左侧和上侧的距离 */
    offset?: Array<number>;
    /**徽标的样式 */
    badgeStyle?: React.CSSProperties;
    /**外层rd-badge的样式 */
    style?: React.CSSProperties;
    className?: string;
    /**有children，则表示徽标会在此children外部 */
    children?: React.ReactNode;
    prefixCls?: string;
}
export interface BadgeState {
    count?: React.ReactNode;
    status?: typeof StatusType[number];
}
export default class Badge extends React.PureComponent<BadgeProps, BadgeState> {
    static defaultProps: BadgeProps;
    state: BadgeState;
    /**监听属性是否有改变 */
    static getDerivedStateFromProps(nextProps: BadgeProps, prevState: BadgeState): BadgeState;
    /**判断是否为小圆点样式 */
    isDot(status: typeof StatusType[number], dot: boolean): boolean;
    /**获取实际显示的count值 */
    getCount(isDot: boolean, count: React.ReactNode): React.ReactNode;
    /**生成徽标内容 */
    generateBadge(isDot: boolean, isBadgeWrapper: boolean, badgeContentStyle: React.CSSProperties, count: React.ReactNode, badgeClassName: string): React.ReactNode;
    /**是否显示dot的text信息 */
    showText(isDot: boolean, text: React.ReactNode, isBadgeWrapper: boolean): boolean;
    /**生成JSX */
    render(): React.ReactNode;
}
export {};
