import React from "react";
import { DropdownProps } from "../dropdown/Dropdown";
import { InputBaseProps } from '../input/Input';
import { IntervalProps } from '../interval/interval';
export declare type Types = 'date' | 'time' | 'week' | 'month' | 'year' | 'daterange' | 'timerange';
export declare type SelectionMode = 'year' | 'month' | 'week' | 'date' | 'range';
export declare type D = Date;
export declare type S = string;
export declare type DS = Date[];
export declare type SS = string[];
export declare type SizeType = 'large' | 'medium' | 'small';
export declare type TimeStr = 'hours' | 'minutes' | 'seconds';
export declare type TimeType = {
    hours?: number;
    minutes?: number;
    seconds?: number;
};
/**
 * 基础接口定义
 */
export declare type Base = {
    showTopText?: boolean;
    readonly?: boolean;
    disabled?: boolean;
    /**大小 */
    size?: SizeType;
    /**是否显示input右侧图标 */
    icon?: boolean;
    suffixIcon?: React.ReactNode;
    /**自定义关闭图标 */
    clearIcon?: React.ReactNode;
    /**是否显示确定按钮  todo暂未实现*/
    okIcon?: boolean;
    /**下拉框组件内置属性 */
    dropDownProps?: DropdownProps;
    /**输入框组件内置属性 */
    inputProps?: InputBaseProps & IntervalProps;
    /**类名 */
    className?: string;
    /**style */
    style?: React.CSSProperties;
    /**是否显示时间 有时间的情况下显示确定按钮 */
    showTime?: boolean;
    /**点击取消按钮的回调 */
    onCancel?: () => void;
    /**聚焦回调 */
    onFocus?: () => void;
    /**失去焦点回调 */
    onBlur?: () => void;
};
/**
 * 日期选择基础接口
 */
export declare type BaseDate = Base & {
    type?: Types;
    format?: string;
    /**周起始日 1 到 7	默认 7 */
    firstDayOfWeek?: number;
};
/**
 * 单日期面板
 */
export declare type DatePickerProps<D, S> = BaseDate & {
    value?: D;
    placeholder?: S;
    /** 是否禁用日期	(Date, selectionMode)=>boolean*/
    disabledDate?: (date: Date) => boolean;
    onChange?: (value: S, e: React.ChangeEvent<HTMLInputElement>, activeIndex: number) => void;
    onPick?: (value: D, text: S) => void;
};
/**
 * 时间选择器基础接口定义
 */
export declare type BaseTime = Base & {
    /**小时：HH，分：mm，秒：ss */
    format?: string;
    hoursStep?: number;
    minutesStep?: number;
    secondsStep?: number;
    fillZero?: boolean;
    scrollClassName?: string;
};
export declare type SelectableRangeDate = Array<Array<Date>>;
/**
 * 时间选择器接口
 */
export declare type TimePickerProps<D, S> = BaseTime & {
    /**
     * 时间范围选择 有bug
     * start表示开始时间段哪些范围可点击，例如[[new Date(),new Date()],[new Date(),new Date()]]
     * end表示结束时间段哪些范围可点击：例如[[new Date(),new Date()],[new Date(),new Date()]]
    */
    /**提示 */
    placeholder?: S;
    /**传入的值 */
    value?: D;
    onChange?: (value: S, e: React.ChangeEvent<HTMLInputElement>, activeIndex: number) => void;
    onPick?: (value: D, text: S) => void;
};
