export declare const DEFAULT_FORMATS: {
    date: string;
    month: string;
    year: string;
    week: string;
    time: string;
    timerange: string;
    daterange: string;
};
export declare const HAVE_TRIGGER_TYPES: string[];
/**
 * 获取date格式化之后的数据
 * @param value 原数据 Date
 * @param format 格式化string
 * @returns value格式化后的数据
 */
export declare const DATE_FORMATTER: (value: Date, format: string) => string;
export declare const DATE_PARSER: (text: string, format: string) => Date;
/**
 * 将Date格式的数据转换为string数组
 * @param value Date[]
 * @param format string
 * @returns string[]
 */
export declare const RANGE_FORMATTER: (value: Date[], format: string) => string[];
export declare const RANGE_PARSER: (text: string[], format: string) => Date[];
export declare const TYPE_VALUE_RESOLVER_MAP: {
    /**
     * 默认处理
     */
    default: {
        /**
         * 格式化value
         * @param value string
         * @returns string
         */
        formatter(value: Date): string;
        /**
         * 格式化text
         * @param text string|Date
         * @returns string|Date
         */
        parser(text: string): string;
    };
    /**
     * 周
     */
    week: {
        /**
         * 获取string类型的周
         * @param value Date 需要格式化的值
         * @param format string 格式化
         * @returns string
         */
        formatter(value: Date, format: string): string;
        /**
         * 获取date类型的周
         * yyyywWW  根据format yyyywWW 格式，获取WW周出现的位置，根据位置获取到传入的周数和年份，根据周和年份计算出所在的日期（Date格式）
         * @param text
         * @param format
         * @returns Date
         */
        parser(text: string, format: string): Date | string;
    };
    /**
     * 日期
     */
    date: {
        formatter: (value: Date, format: string) => string;
        parser: (text: string, format: string) => Date;
    };
    /**
     * 日期+时间
     */
    /**
     * 日期范围
     */
    daterange: {
        formatter: (value: Date[], format: string) => string[];
        parser: (text: string[], format: string) => Date[];
    };
    /**
     * 日期时间范围
     */
    /**
     * 时间范围
     */
    timerange: {
        formatter: (value: Date[], format: string) => string[];
        parser: (text: string[], format: string) => Date[];
    };
    /**
     * 时间
     */
    time: {
        formatter: (value: Date, format: string) => string;
        parser: (text: string, format: string) => Date;
    };
    /**
     *月
     */
    month: {
        formatter: (value: Date, format: string) => string;
        parser: (text: string, format: string) => Date;
    };
    /**
     * 年
     */
    year: {
        formatter: (value: Date, format: string) => string;
        parser: (text: string, format: string) => Date;
    };
    /**
     * 数字
     */
    number: {
        formatter(value: string): string;
        parser(text: string | number): number;
    };
};
export declare const PLACEMENT_MAP: {
    left: string;
    center: string;
    right: string;
};
