"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SELECTION_MODES = exports.DAY_DURATION = void 0;
exports.deconstructDate = deconstructDate;
exports.formatDate = formatDate;
exports.getDateOfISOWeek = getDateOfISOWeek;
exports.getDayCountOfMonth = getDayCountOfMonth;
exports.getDefaultDate = getDefaultDate;
exports.getFirstDayOfMonth = getFirstDayOfMonth;
exports.getOffsetToWeekOrigin = getOffsetToWeekOrigin;
exports.getRangeHours = getRangeHours;
exports.getRangeMinutes = getRangeMinutes;
exports.getRangeSeconds = getRangeSeconds;
exports.getStartDateOfMonth = getStartDateOfMonth;
exports.getWeekNumber = getWeekNumber;
exports.hasClass = hasClass;
exports.isDate = isDate;
exports.newArray = newArray;
exports.nextMonth = nextMonth;
exports.parseDate = parseDate;
exports.prevMonth = prevMonth;
exports.scrollTo = scrollTo;
exports.setRangeData = setRangeData;
exports.toDate = toDate;

var _util = require("../../../libs/utils/util");

var _date = _interopRequireDefault(require("./date"));

/* eslint-disable complexity */

/**
 * 转成date格式
 * @param date 
 */
function toDate(date) {
  return isDate(date) ? new Date(date) : null;
}
/**
 * 判断是否为Date
 * @param date 
 */


function isDate(date) {
  if (date === null || date === undefined) {
    return false;
  }

  if (isNaN(new Date(date).getTime())) {
    return false;
  }

  return true;
}
/**
 * 格式化date
 * @param date Date
 * @param format 格式化string
 * @returns string
 */


function formatDate(date, format) {
  // date变量为Date类型 toDate将date转为Date
  date = toDate(date);

  if (!date) {
    return '';
  } // 格式化date为string类型


  return _date.default.format(date, format || 'yyyy-MM-dd');
}
/**
 * string==>date
 * @param string 
 * @param format 
 */


function parseDate(string, format) {
  return _date.default.parse(string, format || 'yyyy-MM-dd');
}
/**
 * 获取每月的天数
 * @param year 年 number
 * @param month 月 number
 */


function getDayCountOfMonth(year, month) {
  /**
   * 4，6，9，11月为30天
   * 2月 （闰年为29天，其他为28天）
   * 其他为31天
   */
  if (month === 3 || month === 5 || month === 8 || month === 10) {
    return 30;
  }

  if (month === 1) {
    //判断是否为闰年
    if (year % 4 === 0 && year % 100 !== 0 || year % 400 === 0) {
      return 29;
    } else {
      return 28;
    }
  }

  return 31;
}
/**
 * 每个月第一天开始的周数，如3.1号返回1（周一）
 * @param date 
 */


function getFirstDayOfMonth(date) {
  var temp = new Date(date.getTime());
  temp.setDate(1);
  return temp.getDay();
}
/**一天的毫秒数 */


var DAY_DURATION = 86400000;
/**
 * 获取当月第一天的周期偏差
 * @param year 
 * @param month 
 * @param offsetWeek 
 */

exports.DAY_DURATION = DAY_DURATION;

function getStartDateOfMonth(year, month) {
  var offsetWeek = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
  var result = new Date(year, month, 1);
  var day = result.getDay();

  if (day === offsetWeek) {
    result.setTime(result.getTime() - DAY_DURATION * 7);
  } else {
    var offset = getOffsetToWeekOrigin(day, offsetWeek);
    result.setTime(result.getTime() - DAY_DURATION * offset);
  }

  return result;
}
/**
 * 获取周偏移量
 * @export
 * @param {any} day , first day of current month, 1 - 7
 * @param {number} 默认为7周日开头
 * @returns 
 */


function getOffsetToWeekOrigin(day) {
  var offsetWeek = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 7;
  var offset = day >= offsetWeek ? day - offsetWeek : 7 + day - offsetWeek;
  offset = offset === 0 ? 7 : offset;
  return offset;
}
/**
 * 获取当前日期在一年中处于第几周
 * @param src 
 */


function getWeekNumber(src) {
  var date = new Date(src.getTime());
  date.setHours(0, 0, 0, 0); // 周四决定一年 如1.1处于周四，则1.1处于2021第一周 如1.1处于周五，则属于2020最后一周，下一周才为2021第一周，所有1.4号永远为第一周

  date.setDate(date.getDate() + 3 - (date.getDay() + 6) % 7); // 1月4日总是在第一周。

  var week1 = new Date(date.getFullYear(), 0, 4); // 调整到第1周的星期四，计算从日期到第1周的周数。

  return 1 + Math.round(((date.getTime() - week1.getTime()) / 86400000 - 3 + (week1.getDay() + 6) % 7) / 7);
}
/**
 * 根据周数来计算日期
 *  http://stackoverflow.com/questions/16590500/javascript-calculate-date-from-week-number
 * @param w 周数 number
 * @param y 年 number
 */


function getDateOfISOWeek(w, y) {
  var simple = new Date(y, 0, 1 + (w - 1) * 7);
  var dow = simple.getDay();
  var ISOweekStart = simple;

  if (dow <= 4) {
    ISOweekStart.setDate(simple.getDate() - simple.getDay() + 1);
  } else {
    ISOweekStart.setDate(simple.getDate() + 8 - simple.getDay());
  }

  return ISOweekStart;
}
/**
 * 上个月计算
 * @param src 
 */


function prevMonth(src) {
  var year = src.getFullYear();
  var month = src.getMonth();
  var date = src.getDate();
  var newYear = month === 0 ? year - 1 : year;
  var newMonth = month === 0 ? 11 : month - 1;
  var newMonthDayCount = getDayCountOfMonth(newYear, newMonth);

  if (newMonthDayCount < date) {
    src.setDate(newMonthDayCount);
  }

  src.setMonth(newMonth);
  src.setFullYear(newYear);
  return new Date(src.getTime());
}
/**
 * 下个月计算
 * @param src 
 */


function nextMonth(src) {
  var clone = new Date(src.getTime());
  var year = clone.getFullYear();
  var month = clone.getMonth();
  var date = clone.getDate();
  var newYear = month === 11 ? year + 1 : year;
  var newMonth = month === 11 ? 0 : month + 1;
  var newMonthDayCount = getDayCountOfMonth(newYear, newMonth);

  if (newMonthDayCount < date) {
    clone.setDate(newMonthDayCount);
  }

  clone.setMonth(newMonth);
  clone.setFullYear(newYear);
  return clone;
}
/**
 * 获取小时 boolean[]格式 false表示不可点击
 * @param ranges 
 */
// export function getRange(props: TimeSpinnerTypes, type: TimeType, length: number): any[] {
//     const step = props[`${type}Step` as 'hoursStep' | 'minutesStep' | 'secondsStep'];
//     const arr = [];
//     for (let i = 0; i < length; i = i + (step || 1)) {
//         arr[i] = {
//             value: i,
//         };
//     }
//     return arr;
// }

/**
 * 创建数组
 */


function newArray(start, end) {
  var result = [];

  for (var i = start; i <= end; i++) {
    result.push(i);
  }

  return result;
}
/**创建小时数组  格式[boolean, boolean,.....] */


function getRangeHours(range) {
  var hours = new Array(24).fill(true);

  if (range) {
    var disabledHours = [];
    var value = range.map(function (date) {
      return date.getHours();
    });
    disabledHours = disabledHours.concat(newArray(value[0], value[1]));

    if (disabledHours.length) {
      for (var i = 0; i < 24; i++) {
        hours[i] = disabledHours.indexOf(i) !== -1;
      }
    }
  }

  return hours;
}
/**
 * 设置时间范围（分钟）
 * @param arr
 * @param start
 * @param end
 * @param value
 * @returns
 */


function setRangeData(arr, start, end, value) {
  for (var i = start; i < end; i++) {
    arr[i] = value;
  }

  return arr;
}
/**创建分钟数组  格式 [boolean,boolean,....]*/


function getRangeMinutes(range, hour) {
  var minutes = new Array(60).fill(false);

  if (range) {
    var start = range[0];
    var end = range[1];
    var startHour = start.getHours();
    var startMinute = start.getMinutes();
    var endHour = end.getHours();
    var endMinute = end.getMinutes();

    if (startHour === hour && endHour !== hour) {
      minutes = setRangeData(minutes, startMinute, 60, true);
    } else if (startHour === hour && endHour === hour) {
      minutes = setRangeData(minutes, startMinute, endMinute + 1, true);
    } else if (startHour !== hour && endHour === hour) {
      minutes = setRangeData(minutes, 0, endMinute + 1, true);
    } else if (startHour < hour && endHour > hour) {
      minutes = setRangeData(minutes, 0, 60, true);
    } else {
      minutes = setRangeData(minutes, 0, 60, true);
    }
  } else {
    minutes = setRangeData(minutes, 0, 60, true);
  }

  return minutes;
}
/**创建分钟数组  格式 [boolean,boolean,....]*/


function getRangeSeconds(range, hour, minute) {
  var seconds = new Array(60).fill(false);

  if (range) {
    var start = range[0];
    var end = range[1];
    var startHour = start.getHours();
    var startMinute = start.getMinutes();
    var startSecond = start.getSeconds();
    var endHour = end.getHours(); // const endMinute = end.getMinutes();

    var endSecond = end.getSeconds();

    if (startHour === hour && startMinute === minute) {
      seconds = setRangeData(seconds, startSecond, 60, true);
    } else if (endHour === hour && startMinute === minute) {
      seconds = setRangeData(seconds, 0, endSecond, true);
    } else {
      seconds = setRangeData(seconds, 0, 60, true);
    }
  } else {
    seconds = setRangeData(seconds, 0, 60, true);
  }

  return seconds;
}
/**
 * 节点中是否存在classname
 * @param target 
 * @param classname 
 */


function hasClass(target, classname) {
  return (0, _util.classList)(target).contains(classname);
}
/**
 * 面板模式
 */


var SELECTION_MODES = {
  YEAR: 'year',
  MONTH: 'month',
  WEEK: 'week',
  DATE: 'date',
  RANGE: 'daterange'
};
/**
 * 将date格式转成年月周格式
 * @param date Date
 */

exports.SELECTION_MODES = SELECTION_MODES;

function deconstructDate(date) {
  return {
    year: date.getFullYear(),
    month: date.getMonth(),
    week: getWeekNumber(date)
  };
}

var scrollIds = new Map();
/**
 * 时间条滚动缓冲
 * @param element 
 * @param to 
 * @param duration 
 */

function scrollTo(element, to, duration) {
  if (scrollIds.get(element)) {
    // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
    cancelAnimationFrame(scrollIds.get(element));
  }

  if (duration <= 0) {
    scrollIds.set(element, requestAnimationFrame(function () {
      element.scrollTop = to;
    }));
    return;
  }

  var difference = to - element.scrollTop;
  var perTick = difference / duration * 10;
  scrollIds.set(element, requestAnimationFrame(function () {
    element.scrollTop += perTick;

    if (element.scrollTop !== to) {
      scrollTo(element, to, duration - 10);
    }
  }));
}
/**
 * 设置默认时间
 * @returns Date
 */


function getDefaultDate() {
  var defaultValue = new Date();
  defaultValue.setHours(0);
  defaultValue.setMinutes(0);
  defaultValue.setSeconds(0);
  return defaultValue;
}