import * as React from 'react';
import { GetContainer } from "../portal/Portal";
declare const DrawerDirectionTypes: ["left", "top", "bottom", "right"];
declare type DrawerDirection = typeof DrawerDirectionTypes[number];
export interface DrawerProps {
    /** 是否显示 下面提供了一个onChange 来双向绑定 */
    visible?: boolean;
    /** Drawer宽度 */
    width?: string | number;
    /**Drawer高度*/
    height?: string | number;
    /**Drawer样式*/
    style?: React.CSSProperties;
    /**Drawer样式类名称*/
    className?: string;
    /**Drawer触发对象*/
    trigger?: React.ReactElement;
    /**是否可以通过点击 遮罩层 关闭 Dialog*/
    closeOnClickMask?: boolean;
    /**是否可以通过按下 ESC 关闭 Dialog*/
    closeOnPressEscape?: boolean;
    /** Drawer打开方向 **/
    direction?: DrawerDirection;
    /** Drawer的容器 默认为body**/
    getContainer?: GetContainer;
    /**关闭事件**/
    onClose?: React.ReactEventHandler<HTMLElement>;
    /**关闭或者打开模态框事件 和visible 对应**/
    onChange?: (boolean: boolean) => void;
    /**是否需要锁定body**/
    lockScroll?: boolean;
    transitionPrefix?: string;
    maskTransitionName?: string;
}
interface DrawerState {
    visible?: boolean;
    maskVisible?: boolean;
    container?: HTMLElement;
    _visible?: boolean;
}
export default class Drawer extends React.Component<DrawerProps, DrawerState> {
    static defaultProps: {
        showClose: boolean;
        closeOnClickMask: boolean;
        closeOnPressEscape: boolean;
        direction: string;
        getContainer: HTMLElement;
        lockScroll: boolean;
        transitionPrefix: string;
        maskTransitionName: string;
    };
    /**
     *构造函数
     * @param props
     */
    constructor(props: DrawerProps);
    /**
     * 当props变化或者state变化时向state中合并属性
     * @param nextProps
     */
    static getDerivedStateFromProps(nextProps: DrawerProps): null | DrawerState;
    /**
     * 第一次挂载
     */
    componentDidMount(): void;
    /**
     * 卸载
     */
    componentWillUnmount(): void;
    /**
     * 关闭
     * @param e
     */
    handleClose(e: React.KeyboardEvent): void;
    /**
     *keydown事件处理
     * @param e
     */
    handleKeyDown(e: React.KeyboardEvent): void;
    /**
     * 重置Container
     */
    resetContainer(container: HTMLElement, originStyle: string): void;
    /**
     * mask点击关闭
     * @param e
     */
    handleMaskClose(e: React.MouseEvent): void;
    /**
     * trigger的点击事件
     * @param e
     */
    handleTrigger(e: React.MouseEvent): void;
    /**
     * 处理动画离开事件
     */
    handleLeave(): void;
    /**
     * 处理mask动画离开事件
     */
    handleMaskLeave(container: HTMLElement, originStyle: string): void;
    /**
     * 渲染函数
     */
    render(): React.ReactNode;
}
export {};
