import * as React from 'react';
import { PlacementType, TriggerType } from '../popover/Popover';
import DropdownMenu from './DropdownMenu';
import DropdownItem, { DropdownItemProps } from './DropdownItem';
import { Size } from "../../libs/types";
import { GetContainer } from "../portal/Portal";
export interface DropdownProps {
    size?: Size;
    trigger?: TriggerType;
    overlay?: React.ReactNode;
    hideOnClick?: boolean;
    children?: React.ReactElement;
    className?: string;
    style?: React.CSSProperties;
    disabled?: boolean;
    offset?: [number, number];
    /**点击trigger是否对visible取反**/
    clickTriggerRevert?: boolean;
    /**点击popper是否隐藏popper**/
    clickPopperHidden?: boolean;
    onItemClick?: (event: React.MouseEvent, childProp: DropdownItemProps) => void;
    getContainer?: GetContainer;
    placement?: PlacementType;
    /**portal第一帧渲染什么内容 如果写成null之后getContainer的参数就会为null**/
    firstRender?: React.ReactNode;
    /**是否显示箭头**/
    visibleArrow?: boolean;
    /**当overlay显示不下时 是否应该重新布局**/
    flipEnabled?: boolean;
    /**render策略是否使用fixed或者absolute**/
    strategy?: 'fixed' | 'absolute';
    /**boolean
     * true代表弹出框的宽度和children的长度一样
     * false 代表弹出框的宽度由overlay的样式控制
     * minWidth 代表弹出框的最小宽度和children的长度一样
     * **/
    popperWidthSameWithChildren?: boolean | 'minWidth';
    /**得到子类的option**/
    getOptions?: (options: Array<DropdownItemProps>) => void;
    onClose?: () => void;
    onOpen?: () => void;
}
export default class Dropdown extends React.PureComponent<DropdownProps> {
    static defaultProps: {
        trigger: string;
        clickTriggerRevert: boolean;
        hideOnClick: boolean;
        flipEnabled: boolean;
        placement: string;
        visibleArrow: boolean;
    };
    state: {
        visible: boolean;
    };
    static Menu: typeof DropdownMenu;
    static Item: typeof DropdownItem;
    private el;
    private keysOption;
    /**
     * 该方法留给子类调用
     * @param e
     * @param childProp
     */
    private handleItemClick;
    /**
     * 主动关闭弹出框供外部调用
     */
    emitClose(): void;
    /**
     * 渲染函数
     */
    render(): React.ReactElement;
}
