import * as React from 'react';
import FormItem, { Rules, ItemValidResult } from './FormItem';
import { ObjectType, Size } from "../../libs/types";
import DynamicFormList from './DynamicFormList';
export declare type Position = 'right' | 'left' | 'center' | 'top';
interface FormStates {
    UUID?: number;
    _prevProps?: FormProps;
    dynamicFields?: Array<{
        key: string;
        index: number;
    }>;
}
/**@deprecated 该用法被废弃了**/
declare type UseFormFunction = (model: ObjectType) => void;
declare type UseFormObject = {
    ref: Form;
    data: ObjectType;
    setData: (obj: ObjectType) => void;
    _defaultModel?: ObjectType;
};
interface FormProps {
    style?: React.CSSProperties;
    className?: string;
    children?: React.ReactNode;
    defaultModel?: ObjectType;
    /**@deprecated 使用useForm 代替**/
    initObserve?: UseFormFunction | UseFormObject;
    /**需要注意的是使用setData、或者直接修改data的方式是浅复制 数组的话会修改原始值**/
    useForm?: UseFormFunction | UseFormObject;
    rules?: Rules;
    labelPosition?: Position;
    /**如果不设的话会根据下面的children中的label内容自动计算最大值**/
    labelWidth?: string | number;
    labelSuffix?: string;
    statusIcon?: boolean;
    action?: string;
    encType?: string;
    method?: string;
    size?: Size;
    /**form原始表单提交增加的额外数据**/
    extraData?: ObjectType;
    /**必须注意的是target 相当于UUID 必须保证唯一值**/
    target?: string;
    /**当垂直方向空间受限且表单较简单时，可以在一行内放置表单**/
    inline?: boolean;
    responseFromIframe?: boolean;
    onSuccess?: (response: string | ObjectType) => void;
    onSubmit?: (e?: React.FormEvent<HTMLElement>) => void;
    onError?: (err: string) => void;
    onFieldChange?: (e: any, name: string, index: number, propValue: any) => void;
}
interface ValidateResult {
    valid: boolean;
    result?: Array<ItemValidResult>;
    model?: ObjectType;
}
export default class Form extends React.PureComponent<FormProps, FormStates> {
    static defaultProps: {
        labelSuffix: string;
        encType: string;
        method: string;
        responseFromIframe: boolean;
        size: string;
    };
    /**存放prop的数组的**/
    propArrays: Array<string>;
    state: FormStates;
    fields: FormItem[];
    static Item: typeof FormItem;
    private _submit;
    private readonly event;
    static DynamicFormList: typeof DynamicFormList;
    static List: typeof DynamicFormList;
    static createFormElement: (isArray?: boolean) => <T, W extends T, P>(Component: T) => W;
    private formRef;
    private defaultModelCopy;
    private model;
    private _model;
    private initVal;
    /**创建observer
     * @deprecated 使用createForm 代替
     */
    static createObserver(defaultModel?: ObjectType): UseFormObject;
    /**
     * @param defaultModel 默认值
     * ref创建Form引用
     * data 表单域的值
     * setData 给表单域赋值
     */
    static createForm(defaultModel?: ObjectType): UseFormObject;
    /**
     * 构造函数
     * @param props
     */
    constructor(props: FormProps);
    /**
     * 根据defaultModel初始化值
     */
    _batchUpdateModel(): void;
    /**
     * 当props变化和state变化时会将props中的数据合并到state中
     * @param nextProps
     */
    static getDerivedStateFromProps(nextProps: FormProps): FormProps;
    /**
     * 初始化后
     */
    componentDidMount(): void;
    /**
     * 往fields中添加FormItem
     * @param child
     */
    _addField(child: FormItem): void;
    /**
     * 移除FormItem
     * @param field
     */
    _removeField(field: FormItem): void;
    /**
     * 重置Form 只支持重置校验状态
     * propList  是一个prop构成的数组
     */
    resetFields(propList?: Array<string>): void;
    /**
     * 得到最终渲染的model
     */
    private _getValidateModel;
    /**
     * 表单校验的方法
     * @param callback
     */
    validate(callback?: (result: ValidateResult) => void): Promise<ValidateResult>;
    /**
     * 获取一组字段名对应的值
     * @param keys
     */
    getFieldsValue(keys?: string[]): Array<{
        prop: string;
        value: any;
    }>;
    /**
     * 获取字段名对应的值
     * @param prop
     */
    getFieldValue(prop: string): any;
    /**
     * 设置一组字段名对应的值
     * @param fieldData
     */
    setFieldsValue(fieldData?: Array<{
        prop: string;
        value: any;
    }> | Array<[string, any]>): void;
    /**
     * 设置字段名对应的值
     * @param prop
     * @param value
     */
    setFieldValue(prop: string, value: any): void;
    /**
     * 校验某个表单域
     * @param prop
     * @param cb
     */
    validateField(prop: string, cb?: (result: ItemValidResult) => void): Promise<ItemValidResult>;
    /**
     * 校验某个表单域
     * @param propList
     * @param allFinished
     */
    validateFields(propList: Array<string>, allFinished?: (result: ValidateResult) => void): Promise<ValidateResult> | void;
    /**
     * 获取iframe的document
     * @param frame
     */
    private static getDoc;
    /***
     *供原始表单提交
     */
    submit(): void;
    /**
     *处理正常结果
     */
    private _handleResult;
    /**
     * 渲染函数
     */
    render(): React.ReactNode;
}
export {};
