import * as React from 'react';
interface HandlerProps extends React.DOMAttributes<HTMLElement> {
    children: React.ReactElement;
    disabled?: boolean;
    /**在替换之前的处理**/
    onBeforeReplace?: (current: HTMLElement) => void;
    /**在替换之后的处理**/
    onAfterReplace?: () => void;
    /**私有属性不可使用**/
    forwardRef?: any;
}
interface CallbackReturn {
    valid: boolean;
    return: Node;
}
interface ParentNode extends Node {
    UUID?: string;
    insertBeforeCallbacks?: Array<(...params: any[]) => CallbackReturn>;
    replaceChildCallbacks?: Array<(...params: any[]) => CallbackReturn>;
    removeChildCallbacks?: Array<(...params: any[]) => CallbackReturn>;
}
/***
 * 该组件的功能相当于在children之前用一个div去包裹了 事件全部由div捕获处理了 但是最终div是没有显示在页面上的
 */
export default class Handler extends React.PureComponent<HandlerProps> {
    private readonly directlyRef;
    private el;
    state: {
        parentNode?: HTMLElement;
    };
    private readonly key;
    private parentNode;
    private removedSibling;
    private childNodes;
    /**是否挂载完成**/
    private _isMounted;
    /**
     * 构造函数
     * @param props
     */
    constructor(props: HandlerProps);
    /**
     *给ref手动赋值
     * @param node
     */
    assignmentRef(node: Node): void;
    /**
     * 组件挂载完成
     */
    componentDidMount(): void;
    /**
     *在..之前插入
     * @param callee
     * @param newChild
     * @param refChild
     */
    insertBefore(callee: Node, newChild: Node, refChild: ParentNode): CallbackReturn;
    /**
     *替换
     * @param callee
     * @param newChild
     * @param oldChild
     */
    replaceChild(callee: Node, newChild: ParentNode, oldChild: Node): CallbackReturn;
    /**
     *移除
     * @param callee
     * @param oldChild
     */
    removeChild(callee: Node, oldChild: ParentNode): CallbackReturn;
    /**
     * 组件销毁
     */
    componentWillUnmount(): void;
    /**
     *处理聚焦的情况
     * @param e
     */
    handleFocus(e: React.FocusEvent<HTMLElement>): void;
    /**
     * 处理失去聚焦的情况
     * @param e
     */
    handleBlur(e: React.FocusEvent<HTMLElement>): void;
    /**
     * 渲染函数
     */
    render(): React.ReactNode;
}
export {};
