import * as React from 'react';
declare const PlacementTypes: ["top", "top-left", "top-right", "bottom", "bottom-left", "bottom-right"];
declare type PlacementType = typeof PlacementTypes[number];
declare const InfoTypes: ["default", "success", "warning", "info", "error"];
export declare type InfoType = typeof InfoTypes[number];
export interface InfoOptions {
    /**id**/
    /**从顶部弹出时，距离顶部的距离 */
    top?: number;
    /**第一个实例距离顶部的距离 默认值为20**/
    defaultTop?: number;
    defaultBottom?: number;
    /**从底部弹出时，距离底部的距离 */
    bottom?: number;
    /**多个弹窗之间的间距 */
    interval?: number;
    /**提示弹出来的位置 */
    placement?: PlacementType;
    /**消息文字**/
    content?: string | number | null | React.ReactNode;
    /**主题**/
    type?: InfoType;
    /**自定义图标的类名**/
    className?: string;
    /**样式**/
    style?: React.CSSProperties;
    /**显示时间, 毫秒。设为 0 则不会自动关闭**/
    duration?: number;
    /**是否显示图标 */
    showIcon?: boolean;
    /**是否显示关闭按钮**/
    showClose?: boolean;
    closeIcon?: React.ReactElement;
    /**文字是否居中**/
    center?: boolean;
    /**关闭时的回调函数, 参数为被关闭的 message 实例**/
    onClose?: () => void;
    /**Info 距离窗口顶部的偏移量    number**/
    offset?: number;
    /**是否是单例模式**/
    singleton?: boolean;
    /**过度动画名称**/
    transitionName?: string;
}
export interface InfoInstance {
    destroy(): void;
}
export interface InfoClass {
    (options: InfoOptions): InfoInstance;
    success(content: React.ReactNode, duration?: number, options?: InfoOptions): InfoInstance;
    warning(content: React.ReactNode, duration?: number, options?: InfoOptions): InfoInstance;
    info(content: React.ReactNode, duration?: number, options?: InfoOptions): InfoInstance;
    error(content: React.ReactNode, duration?: number, options?: InfoOptions): InfoInstance;
}
declare const Info: InfoClass;
export default Info;
