import * as React from 'react';
import { InputBaseProps } from "../input/Input";
import { ForwardRef, Omit } from "../../libs/types";
export interface IntervalProps extends Omit<InputBaseProps, 'onChange' | 'type' | 'value' | 'defaultValue' | 'regexp' | 'onFocus' | 'onBlur'> {
    gapMark?: string | Array<string>;
    gapWordLimit?: number;
    placeholders?: Array<string>;
    several?: number;
    defaultValue?: Array<string>;
    value?: Array<string>;
    textAlign?: 'center' | 'left' | 'right';
    regexp?: Array<RegExp | ((value: string, pre?: HTMLInputElement, after?: HTMLInputElement) => boolean)>;
    nextKeyCode?: number;
    onChange?: (value: Array<string>, e: React.ChangeEvent<HTMLInputElement>, activeIndex: number) => void;
    onFocus?: (e: React.FocusEvent, index: number) => void;
    onBlur?: (e: React.FocusEvent, index: number) => void;
    /**得到所有input的引用**/
    getInstance?: (instance: Array<HTMLInputElement>) => void;
}
export interface IntervalPropsWidthRef extends IntervalProps, ForwardRef {
}
export interface IntervalStates {
    inputWidth?: number;
    isClearVisible?: boolean;
}
export default class Interval extends React.Component<IntervalPropsWidthRef, IntervalStates> {
    private readonly el;
    state: IntervalStates;
    static defaultProps: {
        defaultValue: string[];
        several: number;
        bordered: boolean;
        gapMark: string;
        size: string;
        placeholders: string[];
    };
    static contextType: React.Context<any>;
    private inputRefs;
    /**
     *
     * @param props
     */
    constructor(props: IntervalPropsWidthRef);
    /**
     * 点击清除的按键
     */
    handleClear(e: React.MouseEvent): void;
    /**
     * 处理值改变事件
     * @param value
     * @param e
     * @param activeIndex
     */
    handleChange(value: Array<string>, e: React.ChangeEvent<HTMLInputElement>, activeIndex: number): void;
    /**
     */
    render(): React.ReactElement;
}
