import * as React from 'react';
import { MenuContextProps } from './MenuContext';
import SubMenu from './SubMenu';
import MenuItem from './MenuItem';
import MenuItemGroup from './MenuItemGroup';
export interface ClickParam {
    index: string | number;
    indexPath: Array<string | number>;
    item: any;
    domEvent: React.MouseEvent<HTMLElement>;
}
declare const MenuMode: ["vertical", "inline"];
declare const SubMenuShowLocation: ["auto", "top", "bottom"];
export interface MenuProps {
    /**模式 */
    mode?: typeof MenuMode[number];
    /**是否只保持一个子菜单的展开，只对inline有效 */
    openUnique?: boolean;
    /**默认当前展开的Submenu菜单项的index数组，在垂直模式下，会导致默认固定会悬浮展开菜单 */
    defaultOpenKeys?: Array<string | number>;
    /**默认根据选中的Item来展开subMenu菜单，比如在初始化时，就可以只指定defaultSelectedKeys，而不用指定defaultOpenKeys，只对inline模式生效 */
    expandOpenKeysByDefaultSelectedKeys?: boolean;
    /**当前展开的SubMenu菜单项的index数组，若openUnique为true，则此数组只有纵向的一组index，若传递了此参数，则表示后续此数据由用户自己维护 */
    openKeys?: Array<string | number>;
    /**默认当前菜单选中的index数组 */
    defaultSelectedKeys?: Array<string | number>;
    /**当前选中菜单项的index数组，一般都为一个，表示单选，若传递了此参数，则表示后续此数据由用户自己维护 */
    selectedKeys?: Array<string | number>;
    /**inline模式下的菜单缩进 */
    inlineIntent?: number | string;
    /**Menu的内联样式 */
    style?: React.CSSProperties;
    /**Menu的类名 */
    className?: string;
    /**Menu的自定义类名 */
    prefixCls?: string;
    /**是否有箭头 */
    hasIndicator?: boolean;
    /**文字是否省略显示 */
    ellipsis?: boolean;
    children?: React.ReactNode;
    /**垂直菜单中，子级菜单弹出的位置，auto表示自动切换，默认为auto */
    verticalShowLocation?: typeof SubMenuShowLocation[number];
    /**用于垂直菜单时，当滚动条在底部，然后有自己弹出，导致滚动条乱跳问题，需要设置滚动条位置保持不动，默认是body的滚动条 */
    getScrollContainer?: () => HTMLElement;
    /**SubMenu展开、关闭的回调，或者是自己维护的方法 */
    onOpenChange?: (openKeys: Array<string | number>, index: string | number, indexPath: Array<string | number>) => void;
    /**点击MenuItem事件回调方法，或者是自己维护的方法 */
    onItemClick?: (param: ClickParam) => void;
}
export interface MenuState {
    openKeys?: Array<string | number>;
    selectedKeys?: Array<string | number>;
    prevProps?: MenuProps;
    defaultOpenKeysBySelectedKeys?: boolean;
}
/** */
export declare function getSelectedPathId(children: React.ReactNode, keys: Array<string | number>, ret: {
    find: boolean;
    openKeys: Array<string | number>;
}): void;
declare class Menu extends React.Component<MenuProps, MenuState> {
    static SubMenu: typeof SubMenu;
    static Item: typeof MenuItem;
    static ItemGroup: typeof MenuItemGroup;
    static isMenu: boolean;
    static defaultProps: MenuProps;
    /**
     * 根据上级传下的openKeys改变当前菜单的展开效果
     * @param nextProps
     * @param prevState
     */
    static getDerivedStateFromProps(nextProps: MenuProps, prevState: MenuState): Partial<MenuState>;
    /**
     *
     * @param props
     */
    constructor(props: MenuProps);
    /**
     * 获取提供给下级调用的方法
     */
    getMenuHandleHook(): MenuContextProps["menuHandleHook"];
    /**
     *
     */
    render(): React.ReactNode;
}
export default Menu;
