import * as React from 'react';
export interface SubMenuProps {
    /**当前subMenu的index属性，为唯一标志，必填 */
    index: string | number;
    /**当前subMenu所在的纵向index路径，不包括本身，若是第一级SubMenu，则没有此属性，此属性不提供给用户，属于自动生成 */
    indexPath?: Array<string | number>;
    /**是否可展开 */
    disabled?: boolean;
    /**标题节点的类名 */
    subMenuClassName?: string;
    /**subMenu的图标（只能放在前面） */
    icon?: React.ReactNode;
    /**标题文字是否省略, 子级的会覆盖父级的此选项 */
    ellipsis?: boolean;
    /**subMenu的标题内容 */
    subMenuTitle?: React.ReactNode;
    className?: string;
    style?: React.CSSProperties;
    prefixCls?: string;
}
export interface SubMenuState {
    verticalOffsetLeft?: number;
    verticalOffsetTop?: number;
    verticalOffsetBottom?: number;
    verticalLocation?: string;
}
export interface VerticalUpdateProps {
    prevScrollTop?: number;
    prevScrollHeight?: number;
    prevParentRect?: DOMRect;
}
export default class SubMenu extends React.Component<SubMenuProps, SubMenuState> {
    static defaultProps: Partial<SubMenuProps>;
    static isSubMenu: boolean;
    static contextType: React.Context<import("./MenuContext").MenuContextProps>;
    subMenuWapper: HTMLElement;
    subMenuSubWrapper: HTMLElement;
    /** */
    constructor(props: SubMenuProps);
    /**
     * mode为垂直模式时，且子级菜单弹出位置固定为top时，当滚动条在底部，鼠标悬浮出现子级菜单，导致滚动条位置改变，需要设置位置保持不变
     *
     */
    getSnapshotBeforeUpdate(): VerticalUpdateProps;
    /**
     * 若有返回更新前的滚动条位置，则若滚动条位置有修改，则手动改变到以前的滚动条位置
     * @param prevProps
     * @param prevState
     * @param prevObj
     */
    componentDidUpdate(prevProps: SubMenuProps, prevState: SubMenuState, prevObj: VerticalUpdateProps): void;
    /**赋值上级内容verticalShowLocation */
    handleClick: React.MouseEventHandler<HTMLElement>;
    handleMouseenter: React.MouseEventHandler<HTMLElement>;
    handleMouseleave: React.MouseEventHandler<HTMLElement>;
    getMenuSubWidth: () => void;
    getIconName: (mode: string, isOpened: boolean, hasIndicator: boolean) => React.ReactNode;
    isChildrenSelected: () => boolean;
    /**判断menuItem是否被选中，若被选中，则subMenu的样式要改变 */
    loopMenuItemRecursively(children: React.ReactNode, keys: Array<string | number>, ret: {
        find: boolean;
    }): void;
    getLocation: (verticalShowLocation: string) => React.CSSProperties;
    /**
     *
     */
    render(): React.ReactNode;
}
