import * as React from 'react';
import { InfoType } from "../../libs/types";
import { GetContainer } from "../portal/Portal";
interface DialogProps {
    width?: number | string;
    style?: React.CSSProperties;
    className?: string;
    divider?: boolean;
    willUnmount?: () => void;
    visible?: boolean;
    title?: React.ReactNode;
    message?: React.ReactNode;
    type?: 'alert' | 'confirm' | 'prompt' | 'dialog';
    okText?: boolean | string;
    cancelText?: boolean | string;
    defaultValue?: string | number;
    placeholder?: string;
    closeOnClickMask?: boolean;
    closeOnPressEscape?: boolean;
    header?: React.ReactNode;
    children?: React.ReactNode;
    footer?: React.ReactNode;
    iconType?: InfoType | false;
    icon?: React.ReactElement;
    onCancel?: (e: React.MouseEvent) => void;
    onOk?: (e: React.MouseEvent) => void;
    /**是否满足匹配的条件才关闭**/
    beforeDestroy?: boolean | RegExp | BeforePrompt;
    /** 挂载的容器 默认为body**/
    getContainer?: GetContainer;
    promise?: {
        resolve: (value: any) => void;
        reject: (value: any) => void;
    };
    _ref?: any;
}
export interface MessageConfig extends Omit<DialogProps, 'promise' | 'willUnmount'> {
    lockScroll?: boolean;
    showInput?: boolean;
}
export interface AlertConfig {
    width?: number | string;
    style?: React.CSSProperties;
    className?: string;
    /**提示标题**/
    title?: React.ReactNode;
    /**提示信息**/
    message?: React.ReactNode;
    /**可见状态**/
    visible?: boolean;
    /**确认按钮的文本 false表示不显示*/
    okText?: boolean | string;
    /**按下esc是否关闭*/
    closeOnPressEscape?: boolean;
    /**按下蒙层是否关闭*/
    closeOnClickMask?: boolean;
    /**图标的类型 false表示不显示*/
    iconType?: InfoType | false;
    /**自定义图标*/
    icon?: React.ReactElement;
    /**当打开对话框时是否锁定body*/
    lockScroll?: boolean;
    /**点击确定回调**/
    onOk?: (e: React.MouseEvent) => void;
    /**点击取消回调**/
    onCancel?: (e: React.MouseEvent) => void;
    /**是否满足匹配的条件才关闭**/
    beforeDestroy?: boolean | RegExp | BeforePrompt;
    /** 挂载的容器 默认为body**/
    getContainer?: GetContainer;
    footer?: RenderSlot;
    children?: React.ReactNode;
    header?: RenderSlot;
    ref?: any;
}
export interface ConfirmConfig extends AlertConfig {
    /**取消按钮的文本*/
    cancelText?: boolean | string;
}
declare type BeforePrompt = (value: any) => boolean | Promise<boolean>;
export interface PromptConfig extends ConfirmConfig {
    /**输入框默认值*/
    defaultValue?: string | number;
    /**输入框提示*/
    placeholder?: string;
    /**是否展示输入框*/
    showInput?: boolean;
}
declare type RenderOK = (ok: React.ReactElement) => React.ReactElement;
declare type RenderCancel = (cancel: React.ReactElement) => React.ReactElement;
declare type RenderSlot = (renderOK?: RenderOK, renderCancel?: RenderCancel) => React.ReactNode;
export interface DialogConfig {
    /**宽度*/
    width?: number | string;
    /**样式*/
    style?: React.CSSProperties;
    /**类名称*/
    className?: string;
    /**是否显示x*/
    showClose?: boolean;
    /**当打开对话框时是否锁定body*/
    lockScroll?: boolean;
    /**分割线*/
    divider?: boolean;
    /**提示标题**/
    title?: React.ReactNode;
    /**按下蒙层是否关闭*/
    closeOnClickMask?: boolean;
    /**按下esc是否关闭*/
    closeOnPressEscape?: boolean;
    /**自定义头部*/
    header?: React.ReactNode;
    /**自定义中间*/
    children?: React.ReactNode;
    /**自定义尾部*/
    footer?: React.ReactNode;
    /** 挂载的容器 默认为body**/
    getContainer?: GetContainer;
}
/**
 * 导出alert函数
 * @param message
 * @param title
 * @param props
 */
export declare function alert(title?: string, message?: string, props?: AlertConfig): Promise<boolean>;
/**
 * 导出confirm函数
 * @param message
 * @param title
 * @param props
 */
export declare function confirm(title?: string, message?: string, props?: ConfirmConfig): Promise<boolean>;
/**
 * 导出prompt函数
 * @param message
 * @param title
 * @param props
 */
export declare function prompt(title?: string, message?: string, props?: PromptConfig): Promise<boolean>;
/**
 * 导出dialog函数
 * @param props
 */
export declare function dialog(props: DialogConfig): {
    destroy: () => void;
};
export {};
