import * as React from 'react';
import { GetContainer } from "../portal/Portal";
interface Position {
    left?: number;
    right?: number;
    top?: number;
    bottom?: number;
}
export interface ModalProps {
    /**是否可见**/
    visible?: boolean;
    /**宽度**/
    width?: string | number;
    /**标题**/
    title?: React.ReactNode;
    /**是否展示x**/
    showClose?: boolean;
    /**是否展示遮罩**/
    mask?: boolean;
    /**样式**/
    style?: React.CSSProperties;
    /**类名称**/
    className?: string;
    children?: React.ReactNode;
    /**自定义头部**/
    header?: React.ReactNode;
    /**自定义尾部**/
    footer?: React.ReactNode;
    /** 是否可以通过点击 遮罩层 关闭 Dialog**/
    closeOnClickMask: boolean;
    /** 是否可以通过按下 ESC 关闭 Dialog**/
    closeOnPressEscape: boolean;
    /**是否需要分割线**/
    divider?: boolean;
    /** 挂载的容器 默认为body**/
    getContainer?: GetContainer;
    /**是否需要锁定body**/
    lockScroll?: boolean;
    /**位置信息**/
    position?: Position;
    /**过度动画名称**/
    transitionName?: string;
    /**ie是否去掉动画**/
    ieWithoutTransition?: boolean;
    /***点击遮罩层或右上角叉或取消按钮的回调**/
    onCancel?: (e: React.MouseEvent<HTMLElement>) => void;
    /**点击确定回调**/
    onOk?: (e: React.MouseEvent<HTMLElement>) => void;
}
export default class Modal extends React.PureComponent<ModalProps> {
    state: {
        leave: boolean;
    };
    static defaultProps: {
        visible: boolean;
        showClose: boolean;
        closeOnClickMask: boolean;
        closeOnPressEscape: boolean;
        lockScroll: boolean;
        ieWithoutTransition: boolean;
        divider: boolean;
        width: string;
        mask: boolean;
        position: {};
        transitionName: string;
    };
    private el;
    private isLongClick;
    /**
     * 初次加載
     */
    componentDidMount(): void;
    /**
     * 将要卸载
     */
    componentWillUnmount(): void;
    /**
     * 处理关闭
     * @param e
     */
    handleClose(e: React.MouseEvent<HTMLElement>): void;
    /**
     * 处理键盘落下
     * @param e
     */
    handleKeyDown(e: KeyboardEvent): void;
    /**
     * 处理mask点击
     * @param e
     */
    handleMaskClose(e: React.MouseEvent<HTMLElement>): void;
    /***
     *主要解决在modal中鼠标按下后移出modal框在松开鼠标的bug
     */
    handleMouseDown(): void;
    /**
     * 确定按钮的点击
     * @param e
     */
    handleOK(e: React.MouseEvent<HTMLButtonElement>): void;
    /**
     * 处理点击内部事件
     */
    static handleClickInner(e: React.MouseEvent<HTMLElement>): void;
    /**
     * 处理鼠标滚动
     */
    handleScroll(e: React.UIEvent<HTMLElement>): void;
    /**渲染modal*/
    renderModal(): React.ReactElement;
    /**
     * 渲染函数
     */
    render(): React.ReactNode;
}
export {};
