import * as React from 'react';
import { InputBaseProps } from "../input/Input";
import { ForwardRef, Omit } from "../../libs/types";
export interface NumberProps extends Omit<InputBaseProps, 'onChange' | 'type'> {
    /**允许正数**/
    allowPositive?: boolean;
    /**允许负数**/
    allowNegative?: boolean;
    /**允许0**/
    allowZero?: boolean;
    /**允许浮点数**/
    allowFloat?: boolean;
    /**允许001这样的形式**/
    allowZeroStart?: boolean;
    /**数字输入框的up和down 图标是否默认显示**/
    upAndDownDefaultVisible?: boolean;
    onChange?: (value: number) => void;
}
export interface NumberPropsWidthRef extends NumberProps, ForwardRef {
}
export default class Number extends React.Component<NumberPropsWidthRef> {
    state: any;
    private readonly input;
    private hoveStyle;
    static defaultProps: {
        /**默认的最大值**/
        max: number;
        /**默认的最小值**/
        min: number;
        /**允许正数**/
        allowPositive: boolean;
        /**允许负数**/
        allowNegative: boolean;
        /**允许0**/
        allowZero: boolean;
        /**允许浮点数**/
        allowFloat: boolean;
        /**数字输入框的up和down 图标是否默认显示**/
        upAndDownDefaultVisible: boolean;
    };
    /**
     * 构造函数
     * @param props
     */
    constructor(props: NumberPropsWidthRef);
    /**
     *观察value值改变 会将props中的值合并到state中
     * 该方法不能删除
     */
    watchValue(): void;
    /**
     * 检查是否可点击
     */
    unClickAble(): boolean;
    /**
     * 数字加1
     */
    handleAdd(): void;
    /**
     * 数字减1
     */
    handleSub(): void;
    /**
     * 处理聚焦事件
     * @param e
     */
    handleFocus(e: React.FocusEvent<HTMLInputElement | HTMLTextAreaElement>): void;
    /**
     * 处理失去焦点事件
     * @param e
     */
    handleBlur(e: React.FocusEvent<HTMLInputElement | HTMLTextAreaElement>): void;
    /**
     * 鼠标移入事件
     */
    handleHover(): void;
    /**
     * 鼠标离开事件
     */
    handleLeave(): void;
    /**
     * 值改变的回调
     * @param e
     */
    handleChange(e: React.ChangeEvent<HTMLInputElement>): void;
    /**
     * 根据实际的prop设置限制输入
     * @param newValue
     * @param callback
     */
    setActualValue(newValue: number | string, callback?: (newValue: any) => void): void;
    /**
     * 设置值在安全值范围之间
     */
    limitValue(value: number | string): string | number;
    /**
     *渲染函数
     */
    render(): React.ReactNode;
}
