import * as React from 'react';
interface OutSideProps {
    children?: JSX.Element;
    onOutSideClick?: (e: React.MouseEvent) => void;
    onClick?: (e: React.MouseEvent) => void;
    onMouseEnter?: (e: React.MouseEvent) => void;
    onMouseLeave?: (e: React.MouseEvent) => void;
    onFocus?: (e: React.FocusEvent) => void;
    onBlur?: (e: React.FocusEvent) => void;
    /**
     * 触发时机 默认为inner
     * inner :只有当你鼠标点击目标后然后鼠标再次点击非目标地方的时候触发
     * 也就是说必须先触发一次 然后才能触发对应的事件
     *
     * outside:一开始点击目标外面就会触发对应的事件
     */
    triggerTiming?: 'inner' | 'outside';
    /**是否只执行一次**/
    once: boolean;
    forwardRef?: any;
}
/**
 * 用于判断点击的地点是否在children中
 */
export default class OutSide extends React.Component<OutSideProps> {
    state: {};
    private readonly el;
    static contextType: React.Context<any>;
    static defaultProps: {
        triggerTiming: string;
        once: boolean;
    };
    /**是否点击了children**/
    private triggerInner;
    /**只执行一次的onOutSideClick**/
    private onceClick;
    private isPropagationStopped;
    /**
     *
     * @param props
     */
    constructor(props: OutSideProps);
    /***
     * 组件加载后
     */
    componentDidMount(): void;
    /**
     * 生成一次执行函数
     */
    generateOnce(): void;
    /**
     * 组件将要卸载
     */
    componentWillUnmount(): void;
    /**
     * 处理鼠标进入
     * @param e
     */
    handleMouseEnter(e: React.MouseEvent): void;
    /**
     * 处理鼠标进入
     * @param e
     */
    handleMouseLeave(e: React.MouseEvent): void;
    /**
     * 生成event
     * @param e
     */
    generateEvent(e: MouseEvent): React.MouseEvent;
    /**
     * 处理组价的事件
     */
    handleCallback(e: MouseEvent): void;
    /**
     *处理内部点击
     * @param e
     */
    handleInnerClick(e: React.MouseEvent<HTMLSpanElement>): void;
    /**
     * 渲染函数
     */
    render(): React.ReactNode;
}
export {};
