import * as React from 'react';
import { InputBaseProps } from '../input/Input';
import { SelectProps } from "../select/Select";
interface PageSizes {
    num: number;
    path: Array<React.ReactNode>;
}
interface PaginationState {
    preCustom?: React.ReactNode;
    nextCustom?: React.ReactNode;
    internalPageSize?: number;
    total?: number;
    pageCount?: number;
    internalPageCount?: number;
    internalCurrentPage?: number;
    currentPage?: number;
    pageSizes?: Array<number>;
    next?: () => void;
    prev?: () => void;
    _prevProps?: PaginationProps;
    background?: boolean;
    small?: boolean;
}
export interface PaginationProps {
    /**select属性 */
    selectProps?: SelectProps;
    preCustom?: React.ReactNode;
    nextCustom?: React.ReactNode;
    jumpMini?: boolean;
    className?: string;
    middlePageNum?: number;
    small?: boolean;
    background?: boolean;
    currentPage?: number;
    pageSizes?: Array<number | PageSizes>;
    pageSize?: number;
    total?: number;
    layout?: string;
    style?: React.CSSProperties;
    frontPage?: boolean;
    clearJumper?: boolean;
    jumpRender?: (renderInput: React.ReactNode, params?: JumpParams) => React.ReactNode;
    onCurrentChange?: (currentPage: number) => void;
    onSizeChange?: (size: number) => void;
}
export declare type JumpParams = PaginationProps | PaginationState | {
    onJump: () => void;
};
export default class Pagination extends React.Component<PaginationProps, PaginationState> {
    static defaultProps: {
        jumpRender: (renderInput: (input?: React.ReactElement<InputBaseProps>) => void) => React.ReactNode;
        small: boolean;
        pageSize: number;
        currentPage: number;
        frontPage: boolean;
        clearJumper: boolean;
        layout: string;
        pageSizes: {
            num: number;
            path: JSX.Element;
        }[];
        middlePageNum: number;
    };
    state: PaginationState;
    /**
         * 构造
         */
    constructor(props: PaginationProps);
    /**
         *
         */
    componentDidMount(): void;
    /**
         * 更新当前页面条数,总条数,总页数
         * @param prevProps
         * @param prevState
         */
    static getDerivedStateFromProps(nextProps: PaginationProps, prevState: PaginationState): PaginationState;
    /**
         * 上一页切换
         */
    pre(): void;
    /**
         * 下一页切换
         */
    next(): void;
    /**
         * 执行改变改变之后的回调
         * @param oldPage
         * @param newPage
         */
    onCurrentChange(oldPage: number, newPage?: number): void;
    /**
         * 获取合法的页码
         * @param value
         */
    static getValidCurrentPage(value: string | number, props: PaginationProps, state: PaginationState): number;
    /**验证页码合法性 */
    static validateCurrent(value: number, internalPageCount: number): number;
    /**
         * 计算总页数
         */
    static internalPageCount(props: PaginationProps, state: PaginationState): number;
    /**
         * 跳到某页
         * @param page
         */
    jumperToPage(page: number): void;
    /**
         * 页码改变
         * @param val
         */
    handleCurrentChange(val: number): void;
    /**
         * 选项改变 函数 [10,20,30,50,100...]
         * @param val
         */
    handleSizeChange(val: number): void;
    /**
         *
         */
    render(): React.ReactNode;
}
export {};
