import * as React from 'react';
import { Base, ForwardRef } from '../../libs/types';
import { InputBaseProps } from "../input/Input";
export interface Slot extends React.DOMAttributes<HTMLSpanElement>, Base {
    style?: React.CSSProperties;
    className?: string;
    children?: React.ReactNode;
    onClick?: (event: React.MouseEvent<HTMLSpanElement>) => void;
}
export interface PasswordType extends React.DOMAttributes<HTMLSpanElement> {
    style?: React.CSSProperties;
    className?: string;
    /**初始是否显示为加密状态**/
    defaultEncrypt?: boolean;
    /**是否显示切换密码图标**/
    showPassword?: boolean;
    /**是否在input获得焦点改变密码为明文失去焦点变成密文 ps 改属性和defaultEncrypt有联动**/
    focusBlurChangePasswordType?: boolean;
    icon?: React.ReactNode;
    onSwitch?: (boolean: boolean) => void;
}
export interface PasswordProps extends Omit<InputBaseProps, 'type'> {
    /**password自定义**/
    password?: PasswordType;
}
export interface PasswordStates {
    passwordType?: boolean;
    focus?: boolean;
}
export interface PasswordPropsWidthRef extends PasswordProps, ForwardRef {
}
export default class Password extends React.Component<PasswordPropsWidthRef, PasswordStates> {
    protected inputRef: React.RefObject<any>;
    state: PasswordStates;
    /**
     * 构造函数
     * @param props
     */
    constructor(props: PasswordPropsWidthRef);
    static defaultProps: {
        password: {
            defaultEncrypt: boolean;
            showPassword: boolean;
            focusBlurChangePasswordType: boolean;
        };
    };
    /**
     * 处理聚焦事件
     * @param e
     */
    handleFocus(e: React.FocusEvent<any>): void;
    /**
     * 处理失去焦点事件
     * @param e
     */
    handleBlur(e: React.FocusEvent<HTMLInputElement | HTMLTextAreaElement>): void;
    /**
     *设置光标位置
     */
    static setCaretPosition(textDom: any, pos: number): void;
    /**
     * 处理密码切换
     */
    handleSwitchPassword(event: React.MouseEvent<HTMLSpanElement>): void;
    /**
     * 得到密码的cursor
     */
    getPasswordCursor(): string;
    /**
     *得到prefix或者suffix
     */
    getFix(): {
        suffix: React.ReactNode | Slot | Array<Slot>;
        prefix: React.ReactNode | Slot | Array<Slot>;
    };
    /**
     * 渲染函数
     */
    render(): React.ReactNode;
}
