import * as React from 'react';
import { ObjectType } from '../../libs/types';
import { GetContainer } from "../portal/Portal";
declare const TriggerTypes: ["hover", "click", "focus"];
export declare type TriggerType = typeof TriggerTypes[number];
declare const PlacementTypes: ["top", "top-start", "top-end", "bottom", "bottom-start", "bottom-end", "left", "left-start", "left-end", "right", "right-start", "right-end"];
export declare type PlacementType = typeof PlacementTypes[number];
declare const clippingParents: "clippingParents";
declare const viewport: "viewport";
declare const beforeRead: "beforeRead";
declare const read: "read";
declare const afterRead: "afterRead";
declare const beforeMain: "beforeMain";
declare const main: "main";
declare const afterMain: "afterMain";
declare const beforeWrite: "beforeWrite";
declare const write: "write";
declare const afterWrite: "afterWrite";
declare type ModifierPhases = typeof beforeRead | typeof read | typeof afterRead | typeof beforeMain | typeof main | typeof afterMain | typeof beforeWrite | typeof write | typeof afterWrite;
declare type State = any;
declare type PositioningStrategy = "absolute" | "fixed";
declare type OptionsGeneric<TModifier> = {
    placement: PlacementType;
    modifiers: Array<TModifier>;
    strategy: PositioningStrategy;
    onFirstUpdate?: (arg0: Partial<State>) => void;
};
declare type Instance = {
    state: State;
    destroy: () => void;
    forceUpdate: () => void;
    update: () => Promise<Partial<State>>;
    setOptions: (options: Partial<OptionsGeneric<any>>) => Promise<Partial<State>>;
};
declare type ModifierArguments<Options extends ObjectType> = {
    state: State;
    instance: Instance;
    options: Partial<Options>;
    name: string;
};
declare type Modifier<Name, Options> = {
    name?: Name;
    enabled?: boolean;
    phase?: ModifierPhases;
    requires?: Array<string>;
    requiresIfExists?: Array<string>;
    fn?: (arg0: ModifierArguments<Options>) => State | void;
    effect?: (arg0: ModifierArguments<Options>) => (() => void) | void;
    options?: Partial<Options>;
    data?: ObjectType;
};
declare type Rect = {
    width: number;
    height: number;
    x: number;
    y: number;
};
declare type Offsets = {
    y: number;
    x: number;
};
declare type OffsetsFunction = (arg0: {
    popper: Rect;
    reference: Rect;
    placement: PlacementType;
}) => [number | null | undefined, number | null | undefined];
declare type Offset = OffsetsFunction | [number | null | undefined, number | null | undefined];
declare type SideObject = {
    top: number;
    left: number;
    right: number;
    bottom: number;
};
declare type Padding = number | Partial<SideObject>;
declare type Boundary = HTMLElement | Array<HTMLElement> | typeof clippingParents;
declare type RootBoundary = typeof viewport | "document";
declare type OffsetOptions = {
    offset: Offset;
};
declare type OffsetModifier = Modifier<"offset", OffsetOptions>;
declare type ApplyStylesModifier = Modifier<"applyStyles", ObjectType>;
declare type ArrowOptions = {
    element: HTMLElement | string | null;
    padding: Padding | ((arg0: {
        popper: Rect;
        reference: Rect;
        placement: PlacementType;
    }) => Padding);
};
declare type RoundOffsets = (offsets: Partial<{
    x: number;
    y: number;
    centerOffset: number;
}>) => Offsets;
declare type ComputeStylesOptions = {
    gpuAcceleration?: boolean;
    adaptive?: boolean;
    roundOffsets?: boolean | RoundOffsets;
};
declare type EventListenersOptions = {
    scroll?: boolean;
    resize?: boolean;
};
declare type FlipOptions = {
    mainAxis: boolean;
    altAxis: boolean;
    fallbackPlacements: Array<PlacementType>;
    padding: Padding;
    boundary: Boundary;
    rootBoundary: RootBoundary;
    altBoundary: boolean;
    flipVariations: boolean;
    allowedAutoPlacements: Array<PlacementType>;
};
declare type TetherOffset = ((arg0: {
    popper: Rect;
    reference: Rect;
    placement: PlacementType;
}) => number) | number;
declare type PreventOverflowOptions = {
    mainAxis: boolean;
    altAxis: boolean;
    boundary: Boundary;
    rootBoundary: RootBoundary;
    altBoundary: boolean;
    /**
     * Allows the popper to overflow from its boundaries to keep it near its
     * reference element
     */
    tether: boolean;
    tetherOffset: TetherOffset;
    padding: Padding;
};
declare type ArrowModifier = Modifier<"arrow", ArrowOptions>;
declare type HideModifier = Modifier<"hide", ObjectType>;
declare type ComputeStylesModifier = Modifier<"computeStyles", ComputeStylesOptions>;
declare type EventListenersModifier = Modifier<"eventListeners", EventListenersOptions>;
declare type FlipModifier = Modifier<"flip", FlipOptions>;
declare type PopperOffsetsModifier = Modifier<"popperOffsets", ObjectType>;
declare type PreventOverflowModifier = Modifier<"preventOverflow", PreventOverflowOptions>;
declare type StrictModifiers = Partial<OffsetModifier> | Partial<ApplyStylesModifier> | Partial<ArrowModifier> | Partial<HideModifier> | Partial<ComputeStylesModifier> | Partial<EventListenersModifier> | Partial<FlipModifier> | Partial<PreventOverflowModifier> | Partial<PopperOffsetsModifier>;
export interface PopoverProps {
    visible?: boolean;
    children?: React.ReactNode;
    className?: string;
    style?: React.CSSProperties;
    trigger?: TriggerType;
    overlay?: React.ReactNode;
    enterAble?: boolean;
    hoverLeaveHidden?: boolean;
    hoverEnterDuration?: number;
    hoverLeaveDuration?: number;
    needWrapper?: boolean;
    visibleArrow?: boolean;
    /**自定义箭头位置 只能传入left top 等定位元素**/
    arrowPosition?: React.CSSProperties;
    /**当overlay显示不下时 是否应该重新布局**/
    flipEnabled?: boolean;
    /**render策略是否使用fixed或者absolute**/
    strategy?: 'fixed' | 'absolute';
    /**react-popper 的配置对象 请参考https://popper.js.org/*/
    modifiers?: Array<StrictModifiers>;
    /**overlay的偏移量 **/
    offset?: [number, number];
    placement?: PlacementType;
    disabled?: boolean;
    borderColor?: string;
    /**指定父类滚动的元素 这个会影响Popover在滚动元素中表现、当popover在滚动元素中不可见时会隐藏、**/
    specScrollParent?: HTMLElement;
    /**点击trigger是否对visible取反**/
    clickTriggerRevert?: boolean;
    /**可见状态改变的回调**/
    onVisibleChange?: (visible: boolean) => void;
    /**点击popper是否隐藏popper**/
    clickPopperHidden?: boolean;
    /**点击内容外部是否隐藏popper */
    clickPopperOutSideHidden?: boolean;
    /**boolean
     * true代表弹出框的宽度和children的长度一样
     * false 代表弹出框的宽度由overlay的样式控制
     * minWidth 代表弹出框的最小宽度和children的长度一样
     * **/
    popperWidthSameWithChildren?: boolean | 'minWidth';
    /** 挂载的容器 默认为body**/
    getContainer?: GetContainer;
    /**portal第一帧渲染什么内容**/
    firstRender?: React.ReactNode;
    /** The eventListeners modifier adds scroll and resize listeners that update the position of the popper when necessary. These are not exhaustive and don't cover the following cases*/
    eventListenerScroll?: boolean;
    /**当trigger ==focus 是生效的元素  由于兼容性限制 这里默认只有['textarea','input','form','select']这几种生效**/
    focusActiveElements?: Array<string>;
}
interface PopoverStates {
    visible?: boolean;
    parent?: HTMLElement;
    /**弹出框的宽度**/
    popperWidth?: number;
    _prevProps?: PopoverProps;
}
export default class Popover extends React.PureComponent<PopoverProps, PopoverStates> {
    static defaultProps: {
        trigger: string;
        popperWidthSameWithChildren: string;
        flipEnabled: boolean;
        enterAble: boolean;
        hoverLeaveHidden: boolean;
        hoverLeaveDuration: number;
        hoverEnterDuration: number;
        visibleArrow: boolean;
        needWrapper: boolean;
        disabled: boolean;
        offset: number[];
        strategy: string;
        placement: string;
        clickPopperHidden: boolean;
        clickPopperOutSideHidden: boolean;
        getContainer: HTMLElement;
        eventListenerScroll: boolean;
        focusActiveElements: string[];
    };
    protected el: any;
    protected parentMountNode: Element;
    protected popper: HTMLElement;
    state: PopoverStates;
    private _isMounted;
    private popperForceUpdate;
    private resizeObserver;
    private parentResizeObserver;
    private _isFocused;
    /**
     * 本组件第一次挂载
     */
    componentDidMount(): void;
    /**
     *处理最终渲染挂载的dom节点
     */
    handleFinallyRender(parentNode: Element): void;
    /***
     * 观察dom变化
     * 参考用途 主要功能是TreeSelect 的tag高度变高后 能自动更新popover的位置
     */
    obServerDom(): void;
    /***
     * 设置popper宽度
     */
    setPopperWidth(): void;
    /**
     * 安全的设置state
     * @param state
     */
    safeSetState(state: PopoverStates): void;
    /**
     * 组件卸载
     */
    componentWillUnmount(): void;
    /**
     * 获取滚动的父类
     */
    getScrollParent(node: HTMLElement): HTMLElement;
    /**
     * 更新父级
     * @param nextProps
     * @param prevState
     */
    static getDerivedStateFromProps(nextProps: PopoverProps, prevState: PopoverStates): PopoverStates;
    /***
     * 处理focus
     */
    handleFocus(e: React.FocusEvent): void;
    /***
     * 处理blur
     */
    handleBlur(e: React.FocusEvent): void;
    /**
     * 处理触发对象事件
     */
    handleMouseEnter(): void;
    /**
     * 处理鼠标离开事件
     */
    handlePopperMouseLeave(e: MouseEvent): void;
    /**
     * 处理鼠标离开事件
     */
    handleMouseLeave(): void;
    /**
     * 供外部调用
     */
    emitClose(): void;
    /**
     * 得到箭头的边框色
     * @param placement
     */
    getBorder(placement: 'top' | 'bottom' | 'right' | 'left'): React.CSSProperties;
    /**
     * 处理鼠标在目标外点击
     * @param e
     */
    handleOutsideClick(e: React.MouseEvent): void;
    /**
     * 处理鼠标点击
     */
    handleClick(focus?: boolean): void;
    /**
     * 弹出框点击
     */
    handlePopoverClick(): void;
    /**
     * 合并modifiers
     */
    combineModifiers(): Array<ObjectType>;
    /**
     * 给ie10打补丁
     * 在ie10下Popper会闪动一下 初始位置计算不正确
     */
    polyfillIE10(ref: {
        firstRender: boolean;
    } & HTMLDivElement): void;
    /**
     * 渲染函数
     */
    render(): React.ReactNode;
}
export {};
