import * as React from 'react';
declare const Types: ["line", "circle"];
export interface ProgressProps {
    /**进度条类型，默认为条形进度条（line） */
    type?: typeof Types[number];
    /**百分比 */
    percent?: number;
    /**条形进度条的高度，或者环形进度条的环形宽度, 默认8px */
    strokeWidth?: number;
    /**环形进度条画布宽度，默认120px */
    width?: number;
    /**仅针对line，文字内容是否在进度条内，默认为false */
    textInside?: boolean;
    /**是否显示文字描述百分比信息，默认为true */
    showText?: boolean;
    /**进度条百分比进度的颜色 */
    color?: string;
    /**进度条背景颜色 */
    bgColor?: string;
    className?: string;
    style?: React.CSSProperties;
    prefixCls?: string;
    /**显示的文字描述和百分比信息 */
    message?: (percent: number) => React.ReactNode;
}
export interface ProgressState {
    percent?: number;
    color?: string;
    bgColor?: string;
    showText?: boolean;
    strokeWidth?: number;
    width?: number;
}
export interface PathStyle {
    /**一般为(周长，周长) */
    strokeDasharray: string;
    /**偏移 */
    strokeDashoffset: string;
    /**填充颜色 */
    stroke?: string;
}
export default class Progress extends React.Component<ProgressProps, ProgressState> {
    static defaultProps: ProgressProps;
    state: ProgressState;
    /**
     * 根据上级传下的百分比，颜色，是否显示内容，改变state
     * @param nextProps
     * @param prevState
     */
    static getDerivedStateFromProps(nextProps: ProgressProps): ProgressState;
    /** 获取相对宽度，在100的画布下的进度条宽度 */
    relativeStrokeWidth(): string;
    /**
     * 绘制的是圆形路径
     * 半径是以线条到中心的距离，而线宽（strokeWidth），线条是在线宽的中间位置，所以要/2 */
    trackPath(): string;
    /**计算周长 */
    perimeter(): number;
    /**进度条样式 */
    circlePathStyle(): PathStyle;
    /**根据内容返回显示的百分比内容或者自定义内容 */
    showTextInfo(prefixCls: string, text: React.ReactNode): React.ReactNode;
    /**生成线型进度条 */
    generateLine(): React.ReactNode;
    /**生成环形进度条 */
    generateCircle(): React.ReactNode;
    /** */
    render(): React.ReactNode;
}
export {};
