/// <reference types="node" />
import * as React from 'react';
interface ScrollBarProps {
    onScroll?: (e: React.MouseEvent<HTMLElement>) => void;
    onScrollFrame?: (values: any) => void;
    onScrollStart?: () => void;
    onScrollStop?: () => void;
    onUpdate?: (values: any) => void;
    renderView?: (props: any) => React.ReactElement;
    renderTrackHorizontal?: (props: any) => React.ReactElement;
    renderTrackVertical?: (props: any) => React.ReactElement;
    renderThumbHorizontal?: (props: any) => React.ReactElement;
    renderThumbVertical?: (props: any) => React.ReactElement;
    tagName?: string;
    thumbSize?: number;
    thumbMinSize?: number;
    hideTracksWhenNotNeeded?: boolean;
    autoHide?: boolean;
    autoHideTimeout?: number;
    autoHideDuration?: number;
    autoHeight?: boolean;
    autoHeightMin?: number | string;
    autoHeightMax?: number | string;
    universal?: boolean;
    className?: string;
    style?: React.CSSProperties;
    children?: React.ReactNode;
    hoverShowTrack?: boolean;
    hideScrollY?: boolean;
}
interface ScrollBarState {
    didMountUniversal: boolean;
}
export default class ScrollBar extends React.PureComponent<ScrollBarProps, ScrollBarState> {
    container: HTMLElement;
    view: HTMLElement;
    viewChildren: HTMLElement;
    trackHorizontal: HTMLElement;
    trackVertical: HTMLElement;
    thumbHorizontal: HTMLElement;
    thumbVertical: HTMLElement;
    hideTracksTimeout: NodeJS.Timeout;
    detectScrollingInterval: NodeJS.Timeout;
    dragging: boolean;
    scrolling: boolean;
    trackMouseOver: boolean;
    viewScrollLeft: number;
    viewScrollTop: number;
    prevPageY: number;
    prevPageX: number;
    lastViewScrollLeft: number;
    lastViewScrollTop: number;
    requestFrameId: number;
    static defaultProps: ScrollBarProps;
    state: ScrollBarState;
    /**
     * 加载完成后
     */
    componentDidMount(): void;
    /**
     *
     */
    componentDidMountUniversal(): void;
    /**更新 */
    componentDidUpdate(): void;
    /**卸载 */
    componentWillUnmount(): void;
    /**获取滚动条左侧 */
    getScrollLeft(): number;
    /**顶部滚动 */
    getScrollTop(): number;
    /**滚动宽度 */
    getScrollWidth(): number;
    /**滚动高度 */
    getScrollHeight(): number;
    /**视图宽度 */
    getClientWidth(): number;
    /**视图高度 */
    getClientHeight(): number;
    /**获取所有参数信息 */
    getValues(): any;
    /**获取水平滑动块宽度 */
    getThumbHorizontalWidth(): number;
    /**获取垂直滑块高度 */
    getThumbVerticalHeight(): number;
    /**获取滚动条左侧位移 */
    getScrollLeftForOffset(offset: number): number;
    /**获取滚动条顶部位移 */
    getScrollTopForOffset(offset: number): number;
    /**往左侧滑动 */
    scrollLeft(left?: number): void;
    /**往顶部滑动 */
    scrollTop(top?: number): void;
    /**滑到左测 */
    scrollToLeft(): void;
    /**滑到顶部 */
    scrollToTop(): void;
    /**滑到右侧 */
    scrollToRight(): void;
    /**滑到底侧 */
    scrollToBottom(): void;
    /**事件注册 */
    addListeners(): void;
    /**移除监听事件 */
    removeListeners(): void;
    /**滑动处理回调 */
    handleScroll(event: any): void;
    /**滑动开始 */
    handleScrollStart(): void;
    /**滑动开始自动隐藏 */
    handleScrollStartAutoHide(): void;
    /**停止滑动 */
    handleScrollStop(): void;
    /**停止滑动自动隐藏 */
    handleScrollStopAutoHide(): void;
    /**窗口resize处理 */
    /**处理水平滑块鼠标按下 */
    handleHorizontalTrackMouseDown(event: any): void;
    /**处理垂直滑块鼠标按下 */
    handleVerticalTrackMouseDown(event: any): void;
    /**处理水平轨道鼠标按下 */
    handleHorizontalThumbMouseDown(event: any): void;
    /**处理垂直轨道鼠标按下 */
    handleVerticalThumbMouseDown(event: any): void;
    /**拖动 */
    setupDragging(): void;
    /**拖动事件注册 */
    teardownDragging(): void;
    /**开始拖动 */
    handleDragStart(event: any): void;
    /**拖动 */
    handleDrag(event: any): boolean;
    /**拖动结束 */
    handleDragEnd(): void;
    /** */
    handleDragEndAutoHide(): void;
    /** */
    handleTrackMouseEnter(): void;
    /** */
    handleTrackMouseEnterAutoHide(): void;
    /** */
    handleTrackMouseLeave(): void;
    /** */
    handleTrackMouseLeaveAutoHide(): void;
    /** */
    showTracks(): void;
    /** */
    hideTracks(): void;
    /** */
    detectScrolling(): void;
    /** */
    raf(callback?: any): void;
    /** */
    update(callback?: any): void;
    /** */
    _update(callback?: any): void;
    /**JSX */
    render(): React.ReactNode;
}
export {};
