"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getInnerHeight = getInnerHeight;
exports.getInnerWidth = getInnerWidth;
exports.getScrollbarWidth = getScrollbarWidth;
exports.getSize = getSize;
exports.getViewHeight = getViewHeight;
exports.isString = isString;
exports.returnFalse = returnFalse;
exports.setCss = setCss;
var scrollbarWidth = false;
/** */

function getInnerHeight(el) {
  var clientHeight = el.clientHeight;

  if (clientHeight === 0) {
    var _getSize = getSize(el),
        height = _getSize.height;

    clientHeight = height;
  }

  var _getComputedStyle = getComputedStyle(el),
      paddingTop = _getComputedStyle.paddingTop,
      paddingBottom = _getComputedStyle.paddingBottom;

  return clientHeight - parseFloat(paddingTop) - parseFloat(paddingBottom);
}
/** */


function getInnerWidth(el) {
  var clientWidth = el.clientWidth;

  if (clientWidth === 0) {
    var _getSize2 = getSize(el),
        width = _getSize2.width;

    clientWidth = width;
  }

  var _getComputedStyle2 = getComputedStyle(el),
      paddingLeft = _getComputedStyle2.paddingLeft,
      paddingRight = _getComputedStyle2.paddingRight;

  return clientWidth - parseFloat(paddingLeft) - parseFloat(paddingRight);
}
/**
 * 获取内容的高度，在不需要垂直滚动条的时候使用
*/


function getViewHeight(el) {
  var offsetHeight = el.offsetHeight;

  if (offsetHeight === 0) {
    // 如果为0，则可能是隐藏的，需要通过getSize来获取
    var _getSize3 = getSize(el),
        height = _getSize3.height;

    return height;
  }

  return offsetHeight;
}
/** */


function getScrollbarWidth() {
  if (scrollbarWidth !== false) {
    return scrollbarWidth;
  }
  /* istanbul ignore else */


  if (typeof document !== 'undefined') {
    var div = document.createElement('div');
    div.setAttribute('style', 'width: 100; height: 100; position: absolute; top: -9999; overflow: scroll; -ms-overflow: scrollbar;');
    document.body.appendChild(div);
    scrollbarWidth = div.offsetWidth - div.clientWidth;
    document.body.removeChild(div);
  } else {
    scrollbarWidth = 0;
  }

  return scrollbarWidth || 0;
}
/**是否为字符串 */


function isString(maybe) {
  return typeof maybe === 'string';
}
/**返回false */


function returnFalse() {
  return false;
}
/**设置CSS样式到DOM上, 用的时候基本上都是小写，后续注意浏览器兼容 */


function setCss(element, properties) {
  if (typeof properties === 'string') {
    element.style.cssText = properties;
  } else {
    for (var propKey in properties) {
      if (properties.hasOwnProperty(propKey)) {
        element.style[propKey] = properties[propKey];
      }
    }
  }
}
/**获取隐藏元素的高度 */


function getSize(elem) {
  var width = 0;
  var height = 0;
  var scrollWidth = 0;
  var scrollHeight = 0;
  var noneNodes = [];
  var nodeStyle = [];
  /**获取隐藏节点 */

  function getNoneNode(node) {
    var display = getStyles(node).getPropertyValue('display'),
        tagName = node.nodeName.toLowerCase();

    if (display !== 'none' && tagName !== 'body') {
      getNoneNode(node.parentNode);
    } else {
      noneNodes.push(node);

      if (tagName !== 'body') {
        getNoneNode(node.parentNode);
      }
    }
  }
  /**这方法才能获取最终是否有display属性设置，不能style.display。*/


  function getStyles(elem) {
    // Support: IE<=11+, Firefox<=30+ (#15098, #14150)
    // IE throws on elements created in popups
    // FF meanwhile throws on frame elements through "defaultView.getComputedStyle"
    var view = elem.ownerDocument.defaultView;

    if (!view || !view.opener) {
      view = window;
    }

    return view.getComputedStyle(elem);
  }
  /**设置样式节点 */


  function setNodeStyle() {
    var i = 0;

    for (; i < noneNodes.length; i++) {
      var _noneNodes$i$style = noneNodes[i].style,
          visibility = _noneNodes$i$style.visibility,
          display = _noneNodes$i$style.display;
      var style = noneNodes[i].getAttribute("style"); //覆盖其他display样式

      noneNodes[i].setAttribute("style", "visibility:hidden; " + style + "; display:block;");
      nodeStyle[i] = {
        visibility: visibility,
        display: display
      };
    }
  }
  /**还原样式 */


  function resumeNodeStyle() {
    var i = 0;

    for (; i < noneNodes.length; i++) {
      noneNodes[i].style.visibility = nodeStyle[i].visibility;
      noneNodes[i].style.display = nodeStyle[i].display;
    }
  }

  getNoneNode(elem); //获取多层display：none;的元素

  setNodeStyle();
  width = elem.clientWidth;
  height = elem.clientHeight;
  scrollWidth = elem.scrollWidth;
  scrollHeight = elem.scrollHeight;
  resumeNodeStyle();
  return {
    width: width,
    height: height,
    scrollWidth: scrollWidth,
    scrollHeight: scrollHeight
  };
}