import * as React from 'react';
import Option from './Option';
import { Omit, Size } from '../../libs/types';
import { Slot } from "../input/Input";
import { ItemValue } from "../tag/TagGroup";
import { DropdownItemProps } from "../dropdown/DropdownItem";
import { PlacementType } from "../popover/Popover";
import { GetContainer } from "../portal/Portal";
export interface TagValue {
    label?: string | number | undefined | null | boolean;
    value?: string | number | undefined | null | boolean;
    userDefined?: boolean;
}
interface SelectStates {
    _prevProps?: SelectProps;
    children?: React.ReactNode;
    suffix?: React.ReactNode;
    visible?: boolean;
    value?: Value;
    selectedLabel?: string | number | undefined | null | boolean;
    optionMinWidth?: number;
    hoverIndex?: number;
    writable?: boolean;
    focus?: boolean;
    searchValue?: string;
    allListData?: Array<any>;
    showListData?: Array<any>;
    index?: number;
    isListAdd?: boolean;
    scrollTop?: number;
}
declare type Value = string | number | undefined | null | boolean;
export interface SelectProps extends Omit<React.DOMAttributes<HTMLDivElement>, 'onChange'> {
    ellipsis?: boolean;
    /**值 可与下面的onChange双向绑定**/
    value?: Value | Array<TagValue>;
    /**默认值**/
    defaultValue?: Value | Array<TagValue>;
    /**当option userDefined属性为true 那么在input框中如何格式化显示内容**/
    formatter?: (value: Value) => string;
    /**是否允许清空**/
    allowClear?: boolean;
    /**name原生属性**/
    name?: string;
    /**title**/
    title?: string;
    /**是否只读**/
    readOnly?: boolean;
    /**样式**/
    style?: React.CSSProperties;
    /**类名称**/
    className?: string;
    /**弹出框类名称**/
    popoverClassName?: string;
    /**提示**/
    placeholder?: string;
    /**是否使用自定义滚动条 */
    useCustomScrollBar?: boolean;
    /**值改变的回调**/
    onChange?: (value: Value | Array<TagValue>) => void;
    /**点击的回调**/
    onClick?: (e: React.MouseEvent) => void;
    /**option点击的回调**/
    onOptionClick?: (e: React.MouseEvent, childProps: DropdownItemProps) => void;
    key?: string;
    /**尺寸**/
    size?: Size;
    /**是否禁用**/
    disabled?: boolean;
    /**是否多选**/
    multiple?: boolean;
    /**是否可搜索 */
    searchable?: boolean;
    /**options的最大高度**/
    maxHeight?: number;
    /**options的最大宽度**/
    maxWidth?: number;
    /** 虚拟列表的高度 */
    listHeight?: number;
    /**虚拟列表 options 的高度 */
    itemHeight?: number;
    /**虚拟列表 options 的数据 */
    customOption?: any[];
    /**虚拟列表 options 的模板 */
    customOptionTemp?: (customOption: any[], item: any, index: number) => React.ReactNode;
    /**虚拟列表 搜索 */
    onCustomOptionSearch?: (searchValue?: string, customOption?: any[]) => any[];
    /**是否有边框**/
    bordered?: boolean;
    /**前缀自定义--位于边框内部**/
    prefix?: React.ReactNode | Slot | Array<Slot>;
    /**后缀自定义--位于边框内部**/
    suffix?: React.ReactNode | Slot | Array<Slot>;
    /**前缀自定义--位于边框外部**/
    prepend?: React.ReactNode;
    /**后缀自定义--位于边框外部**/
    append?: React.ReactNode;
    status?: Slot;
    /**根据内容自适应宽度**/
    fitSize?: boolean;
    /**render策略是否使用fixed或者absolute**/
    strategy?: 'fixed' | 'absolute';
    /** Option的容器 默认为body**/
    getContainer?: GetContainer;
    /**放置位置**/
    placement?: PlacementType;
    /**portal第一帧渲染什么内容 如果写成null之后getContainer的参数就会为null**/
    firstRender?: React.ReactNode;
    offset?: [number, number];
    /**自带的箭头图标，是否可以触发focus，blur方法 */
    arrowTriggerFocus?: boolean;
    /**自定义搜索方法 */
    onCustomSearch?: (searchVal?: string, children?: React.ReactNode) => React.ReactNode;
}
declare const SelectContext: React.Context<any>;
export { SelectContext };
export default class Select extends React.Component<SelectProps, SelectStates> {
    state: {
        value: string;
        visible: boolean;
        hoverIndex: number;
        optionMinWidth: number;
        writable: boolean;
        selectedLabel: string;
        focus: boolean;
        searchValue: string;
        index: number;
        allListData: JSX.Element[];
        showListData: JSX.Element[];
        isListAdd: boolean;
        scrollTop: number;
    };
    static defaultProps: {
        multiple: boolean;
        bordered: boolean;
        disabled: boolean;
        useCustomScrollBar: boolean;
        size: string;
        fitSize: boolean;
        getContainer: HTMLElement;
        offset: number[];
        arrowTriggerFocus: boolean;
        searchable: boolean;
        formatter: (value: string) => string;
    };
    protected select: HTMLDivElement;
    protected tag: HTMLDivElement;
    static Option: typeof Option;
    private options;
    private dropdown;
    private dropdownMenu;
    private tagGroup;
    private values;
    static contextType: React.Context<any>;
    private inputRef;
    private userDefined;
    /**
     * 构造函数
     * @param props
     */
    constructor(props: SelectProps);
    /**
     * 处理警告
     */
    warning(): void;
    /**
     * 加载后
     */
    componentDidMount(): void;
    /**
     *统一处理change
     */
    handleUnifiedChange(e: Value | Array<TagValue>): void;
    /**
     * 处理option点击
     * @param e
     * @param childProps
     */
    handleOptionClick(e: React.MouseEvent, childProps: DropdownItemProps): void;
    /**
     * 处理input中的select点击
     * @param e
     */
    handleClick(e: React.MouseEvent<HTMLDivElement>): void;
    /**
     * 处理tag关闭
     * @param tag
     * @param e
     */
    handleTagClose(tag: Array<ItemValue>, e: React.MouseEvent<HTMLOrSVGElement>): void;
    /***
     * 处理打开或者关闭
     */
    handleOpenClose(visible: boolean): void;
    /**
     *
     * @param e
     */
    handleClear(e: React.MouseEvent<HTMLElement>): void;
    /**
     * 处理失去焦点事件
     */
    handleBlur(e: React.FocusEvent<HTMLInputElement>): void;
    /**
     * 处理获得焦点
     */
    handleFocus(e: React.FocusEvent<HTMLInputElement>): void;
    /**
     * 处理input onChange
     * @param e
     */
    handleChange(e: React.ChangeEvent<HTMLInputElement>): void;
    /**focus图标的处理 */
    handleArrowTriggerFocus(e: React.MouseEvent<HTMLElement>): void;
    /**搜索事件处理 */
    handleSearchChange(value: string): void;
    /**
     * 渲染options
     */
    renderOptions(): React.ReactElement;
    /**
     * 通过value得到label
     * @param value
     */
    getLabelByValue(value: Value): string;
    /**
     * 获得Value
     */
    getTagValue(): any;
    /**
     * 渲染input
     */
    renderInput(): React.ReactElement;
    /**
     * 主动关闭弹出框供外部调用
     */
    emitClose(): void;
    /**
     * 渲染函数
     */
    render(): React.ReactNode;
}
