import * as React from 'react';
declare type ValType = string | number;
export interface SliderProps {
    /**滑块的值 */
    value?: ValType;
    /**滑块的最小值，默认为0 */
    min?: ValType;
    /**滑块的最大值，默认为100 */
    max?: ValType;
    /**滑动的步长，默认为1 */
    step?: ValType;
    /**是否允许滑动，默认为false */
    disabled?: boolean;
    /**是否显示tooltip，默认true */
    tooltipVisible?: boolean;
    /**slider前的范围描述信息 */
    rangeInfoPre?: React.ReactNode;
    /**slider后的范围描述信息 */
    rangeInfoSuffix?: React.ReactNode;
    /**是否有输入框 */
    hasInput?: boolean;
    /**是否有带icon的输入框 */
    hasInputIcon?: boolean;
    extraInfo?: (value: number) => React.ReactNode;
    className?: string;
    style?: React.CSSProperties;
    prefixCls?: string;
    onChange?: (value: number) => void;
    onEnd?: (value: number) => void;
}
export interface SliderState {
    /**存储的props中的value值 */
    propsValue?: number;
    value?: number;
    inputValue?: ValType;
    dragging?: boolean;
    disabled?: boolean;
}
export interface TrackPosition {
    pageX: number;
    /**当前滑块在slider上的百分比值 */
    startPosition: number;
}
export default class Slider extends React.PureComponent<SliderProps, SliderState> {
    static defaultProps: SliderProps;
    state: SliderState;
    /**初始化后要更新滑块位置 */
    componentDidMount(): void;
    trackPosition: TrackPosition;
    sliderRailRef: React.RefObject<HTMLDivElement>;
    /**监听value，disabled状态 */
    static getDerivedStateFromProps(nextProps: SliderProps, prevState: SliderState): Partial<SliderState>;
    /**判断是否为touch事件 */
    isTouchEvent(e: React.TouchEvent): boolean;
    /**滑块事件 */
    handleMouseDown(event: React.MouseEvent): void;
    /**设置滑块的位置 */
    setPositionValue(event: React.MouseEvent | React.TouchEvent): number;
    /**处理移动事件 */
    handleMouseMove: (...args: any) => void;
    /**鼠标松开事件处理 */
    handleMouseUp(): void;
    /**移动端事件处理 */
    handleTouchStart(event: React.TouchEvent): void;
    handleTouchMove: (...args: any) => void;
    /**移动结束 */
    handleTouchEnd(): void;
    /**设置鼠标按下滑块位置 */
    setHandlePosition(event: React.MouseEvent | React.TouchEvent, type: string): void;
    /**设置滑块的位置，初始化，以及点击按钮时 */
    setTrackPosition(pageX?: number): void;
    /**当前滑块在slider上的百分比值 */
    currSliderPosition(): number;
    /**根据Position百分比值设置slider的值value */
    setSliderPosition(position: number): number;
    /**slider的实际宽度，px */
    getSliderWidth(): number;
    /**添加事件 */
    addDocumentEvent(type: string): void;
    /**移除事件 */
    removeDocumentEvent(type: string): void;
    /**点击slider事件 */
    handleClickSlider(event: React.MouseEvent | React.TouchEvent): void;
    /**处理输入框失去焦点操作 */
    handleInputBlur(event: React.FocusEvent<HTMLInputElement>): void;
    /**输入框内容改变处理 */
    handleInputChange(event: React.ChangeEvent<HTMLInputElement>): void;
    /**处理减操作 */
    handleMinus(): void;
    /**处理加操作 */
    handlePlus(): void;
    /**判断value值是否有效 */
    validValue(value: ValType): boolean;
    /**判断是否有额外信息 */
    hasExtraInfo(): boolean;
    /**生成Input输入框 */
    generateInput(prefixCls: string): React.ReactNode;
    /**生成JSX */
    render(): React.ReactNode;
}
export {};
