import * as React from 'react';
import { TableProps, Column, TableState, SortOrderType, StrOrNum, DataTypes } from './Types';
import DynamicList from '../dynamic-list';
export default class Table extends React.Component<TableProps, TableState> {
    el: HTMLElement;
    headerWrapper: HTMLElement;
    bodyWrapper: HTMLElement;
    resizeProxy: HTMLElement;
    bodyScrollWrapper: DynamicList;
    trHeight: number;
    isSupSkicky: boolean;
    static defaultProps: {
        showHeader: boolean;
        editCoordinate: {
            key: (string | number)[];
            prop: (string | number)[];
        };
        /**默认滚动高度动态加载数据 */
        listView: boolean;
        search: {};
        hasSortNull: boolean;
        useCustomScrollBar: boolean;
    };
    resize: boolean;
    /**
     * 构造函数
     * @param props
     */
    constructor(props: TableProps);
    /**
     * 筛选所有可选中的数据
     * @returns
     */
    getSelectableData(data?: Array<DataTypes>, _columns?: Column[]): Array<DataTypes>;
    /**
     * 获取单页选中还是全选的数据
     */
    getSelectData(dataSource?: Array<DataTypes>, data?: Array<DataTypes>, showData?: Array<DataTypes>): Array<DataTypes>;
    /**
     * 表头全选按钮判断是否选中
     */
    get isAllSelected(): {
        selectAll: boolean;
        selectedData: Array<DataTypes>;
        selectedDataSource: Array<number | string>;
    };
    /**
     * 浏览器缩放监听宽度高度
     */
    onResize(): void;
    /** * 初始化 */
    componentDidMount(): void;
    /**
     * 排序时，更新固定列样式
     * */
    componentDidUpdate(prevProps: TableProps): void;
    /**
     * 销毁resize
     */
    componentWillUnmount(): void;
    /**
     * 获取原始data数据+key值的封装数据
     * @returns [
     *   {
     *      key:xx,
     *      data:{xxx}
     *   }
     * ]
     */
    getDataSource(): Array<DataTypes>;
    /**
     * 获取选中的key值
     * @returns [key1,key2,...]
     */
    updateSelectedRowKeys(data: Array<DataTypes>, params: any): any;
    /**
     * colums数据处理
     * @param columns 获取表格高度
     */
    updateColumns(): TableState;
    /**
     * data数据更新处理,data,搜索，排序，分页
     * key哪个变化就传哪个，data，search，sort，page关键字
     * @param props
     */
    updateData(params?: any): TableState;
    /**
     * 首次渲染页面，如果有动态加载数据，返回空，避免过多渲染占用时间
     */
    firstRenderBodyData(showData: Array<DataTypes>): Array<DataTypes>;
    /**
     * 判断是否需要动态计算显示数据
     */
    calcDymanicData(): boolean;
    /**
     * 计算table宽度
     */
    caculateWidth(column?: Column): void;
    /**拖动后更新高度 */
    scheduleLayout(column?: Column): void;
    /**
     * row改变时执行
     * @param row
     */
    handleRowChange(rowKey: StrOrNum): void;
    /**
     * 判断是否全部选中
     */
    toggleAllSelection(keys: Array<string | number>, event: any, row?: any): void;
    /**
     * 页码改变执行的回调
     */
    pageChange(key: string, value: number): void;
    /**
     * 页码选项改变
     * @param val
     */
    handleSizeChange(pageSize: number): void;
    /**
     * 页码改变
     * @param page
     */
    handleCurrentChange(currentPage: number): void;
    /**
     * 点击头部排序
     */
    onHeaderSortClick(column: Column, givenOrder: SortOrderType, event: React.MouseEvent): void;
    /**
     * body滚动
     */
    handleBodyScroll(e: React.UIEvent, data?: any[]): void;
    /**
     * 浮动位置
     */
    fixedWidth(): void;
    /**
     * 获取真实宽度
     * @param column
     * @returns
     */
    getTrWidth(width: string | number, bodyWidth?: number): number;
    /**
     * 是否有纵向滚动条
     *当有tableHeight，也就是固定头，只滚动body时，是否存在纵向滚动条
    */
    hasScrollY(): boolean;
    /**
     *
     */
    getTdWidth(column: Column): number | string;
    /**
     * 表头
     */
    headerTableRender(): React.ReactNode;
    /**
     * 表body
     */
    bodyTableRender(): React.ReactNode;
    /**
     * footer
     */
    footerTableRender(): React.ReactNode;
    /**
     * 渲染
     */
    render(): React.ReactNode;
}
