import React from "react";
export declare type StrOrNum = string | number;
export declare type AnyStr = undefined | null | string | number | symbol | boolean | ObjType;
export interface ObjType {
    key?: StrOrNum;
    [key: string]: any;
}
export interface DataTypes {
    key: StrOrNum;
    data: ObjType;
    index?: number;
}
declare const SortOrderTypes: ["ascending", "descending"];
export declare type SortOrderType = typeof SortOrderTypes[number];
declare const AlignTypes: ["left", "center", "right"];
export declare type AlignType = typeof AlignTypes[number];
declare const FixedTypes: ["left", "right"];
export declare type FixedType = typeof FixedTypes[number];
declare const IndexTypes: ["index", "radio", "checkbox"];
export declare type IndexType = typeof IndexTypes[number];
/** * order排序方式ascending升序
 * descending降序 排序字符串参照string还是number排序 ，
 * single true单页排序，false多页排序，
 * customMethod自定义排序，当为自定义排序时，order，type，single均失效
 * */
export interface SortType {
    order?: SortOrderType;
    type?: StrOrNum;
    single?: boolean;
    customMethod?: (a: ObjType, b: ObjType, order: SortOrderType) => number;
}
/**
 * 列上的属性
 */
export declare type Column = {
    title?: boolean;
    /**列的类型，支持index索引序号，radio多选，checkbox多选 */
    type?: IndexType;
    /**列表头显示文字 */
    label?: React.ReactNode;
    /**列关联字段 */
    prop?: string;
    /**列宽度 */
    width?: number | string;
    /**列的最小宽度 */
    minWidth?: number | string;
    /**列固定 值为true时默认为固定在左侧 */
    fixed?: FixedType | true;
    /**排序 true为默认排序 */
    sortOrder?: SortType | boolean;
    /**body对齐方式左中右 */
    align?: AlignType;
    /**头部对齐方式 */
    headerAlign?: AlignType;
    /**对应列的类名 */
    className?: string;
    /**label文字的类名 */
    labelClassName?: string;
    /**横跨多少列 */
    rowSpan?: number;
    /**纵跨多少行 */
    colSpan?: number;
    /**对应列是否可以通过拖动改变宽度（需要在table上设置border属性为真） */
    resizable?: boolean;
    /**子列，用于复杂头部构成 */
    subColumns?: Array<Column>;
    /**是否可编辑 */
    editable?: boolean;
    /**表头省略 */
    headEllipsis?: boolean;
    /**表格td省略 */
    ellipsis?: boolean;
    /**层级深度 */
    level?: number;
    /**编辑时的DOM */
    editDom?: (row: ObjType, column: Column, key: StrOrNum) => React.ReactNode;
    /**对应列哪些是可选择的回调。返回true/false 默认为checkbox和radio禁用*/
    selectable?: (row: ObjType, key: StrOrNum, index: number) => boolean;
    /**渲染，格式化数据 */
    render?: (row: ObjType, column: Column, key: StrOrNum) => React.ReactNode;
    /**格式化表头 */
    renderHeader?: (column: Column) => React.ReactNode;
    /**拖动后端回调 */
    onHeaderDragEnd?: (columnWidth?: string | number, oldWidth?: string | number, column?: Column, event?: MouseEvent) => void;
};
export declare type ColType = Column;
/**
 * 展开相关属性
 */
export interface ExpandAble {
    /**展开内容的类名 */
    className?: (record: Column, index: number) => string;
    /**展开内容 */
    render?: (record: Column, index: number) => React.ReactNode;
    /**展开图标 */
    openIcon?: (record: Column, index: number) => React.ReactNode;
    /**关闭图标 */
    closeIcon?: (record: Column, index: number) => React.ReactNode;
    /**是否允许展开 */
    expendable?: (record: Column, index: number) => boolean;
    /**是否可以点击行来展开 */
    rowByClick?: boolean;
    /**当前展开的行 */
    expandedRowKeys?: (record: Column, index: number) => boolean;
    /**打开回调 */
    onOpen?: (record: Column, index: number) => void;
    /**关闭回调 */
    opClose?: (record: Column, index: number) => void;
}
/**
 * 表格上的props属性
 */
export interface TableProps {
    useCustomScrollBar?: boolean;
    fixedFooter?: boolean;
    hasSortNull?: boolean;
    tableDataRealLength?: number;
    singleSelectAll?: boolean;
    cellPlaceholder?: React.ReactNode;
    keyWordClassName?: string;
    sortIcon?: {
        ascending: React.ReactNode;
        descending: React.ReactNode;
    };
    sortSingleColumn?: boolean;
    sortSingleIcon?: boolean;
    selectableRow?: boolean;
    /**
     * 配置展开属性
     */
    expandable?: ExpandAble;
    trHeight?: number;
    /**是否loading显示 */
    loading?: boolean;
    /**loading自定义组件 */
    loadComp?: React.ReactNode;
    /**搜索
     * keyword关键字
     * isCase 是否区分大小写
     * condition需要搜索的列，对应colunm的prop值
     */
    search?: {
        keyword: string;
        isCase?: boolean;
        condition?: Array<string>;
    };
    /**表格样式,
     * 如果在style里面设置高度或者在css里面设置高度，表示整个rd-table的高度，包括表头上面内容部分，表格下面页码及其他部分，
     * 如果要设置表格单独的高度，可在height属性或者headerHeight，tableHeight，footerHeight里面设置
     * */
    style?: React.CSSProperties;
    bodyStyle?: React.CSSProperties;
    /**表格类名 挂在在rd-table上*/
    className?: string;
    /**表格rd-table最大高度 */
    maxHeight?: number;
    /**表格rd-table的最大宽度 */
    maxWidth?: number;
    /**表格rd-table的宽度 */
    width?: number;
    /**表格rd-table的高度 */
    height?: number;
    /**样式是否为斑马纹，也就是隔行换色 */
    stripe?: boolean;
    /**表格是否有边框 */
    border?: boolean;
    /**是否显示表头 */
    showHeader?: boolean;
    /**当前表格选择的行key值，多选 */
    currentRowKey?: Array<StrOrNum>;
    /**每行的类名 */
    rowClassName?: ((row: ObjType, index: number) => string);
    /**表格数据为空时，显示的文字 */
    emptyText?: string;
    /**自定义空组件 */
    emptyComp?: React.ReactNode;
    /**是否在表格里面单独作为一行显示 */
    emptyTableInner?: boolean;
    /**表格内容高度 */
    tableHeight?: number;
    /**表格数据 */
    data: Array<ObjType>;
    /**表头配置信息 */
    columns: Array<Column>;
    /**自定义表格底部内容 */
    footer?: React.ReactNode;
    /**自定义表格顶部内容，header并非表格的header */
    header?: React.ReactNode;
    /**当前选中的rowkey 单选 */
    selectRowKey?: StrOrNum;
    /**分页的配置信息 */
    pagination?: any;
    /**可编辑定位
     * [key,prop]
     * 如果只传row的key值
     */
    editCoordinate?: {
        keys?: Array<StrOrNum>;
        props?: Array<StrOrNum>;
    };
    /**是否为迷你小表格 */
    mini?: boolean;
    /**分页是否在表格里面 */
    pageInner?: boolean;
    /**listView 固定每行行高按需加载，只加载滚动区域数据 */
    listView?: {
        num: number;
    } | boolean;
    /**每行的样式 */
    rowStyle?: (row: ObjType, index: number) => React.CSSProperties;
    /**每行的key，必须唯一，否则会造成查找对应行数据不准的问题 */
    rowKey?: ((row: ObjType, index?: number) => StrOrNum);
    /**点击当前行执行的回调 */
    onRowClick?: (row: ObjType, key: StrOrNum, event: React.MouseEvent) => void;
    /**点击页码执行的回调 */
    onCurrentChange?: (val: number) => void;
    /**radio和checkbox勾选执行的回调 */
    onSelectChange?: (keys: StrOrNum | StrOrNum[], row: ObjType, event: React.MouseEvent) => void;
    /**全选执行的回调 */
    onSelectAll?: (keys: Array<StrOrNum> | StrOrNum, event: React.MouseEvent) => void;
    /**分页下拉框选择的回调 */
    onSizeChange?: (size: StrOrNum) => void;
    /**点击排序的回调 */
    onSortClick?: (order: SortOrderType, column: Column, event: React.MouseEvent) => void;
    /**表头th点击事件 */
    onThClick?: (column: Column, event: React.MouseEvent) => void;
    /**点击单元格的回调 */
    onCellClick?: (row: ObjType, data: AnyStr, column: Column, event: React.MouseEvent) => void;
    /**鼠标移入事件 */
    onMouseEnter?: (row: ObjType, data: AnyStr, column: Column, event: React.MouseEvent) => void;
    /**鼠标移出事件 */
    onMouseLeave?: (row: ObjType, data: AnyStr, column: Column, event: React.MouseEvent) => void;
    onSearch?: (data: Array<DataTypes>) => void;
}
export interface TableState {
    /**表头多列遍历渲染数组 */
    columnRows?: Array<Array<Column>>;
    /**左边固定列 */
    fixedColumns?: Array<Column>;
    /**列数据 */
    columns?: Array<Column>;
    /**右边固定列 */
    rightFixedColumns?: Array<Column>;
    /**选中的行key 多选*/
    selectedRowKeys?: StrOrNum[];
    /**显示的数据 */
    data?: Array<DataTypes>;
    /**将要显示的所有数据 */
    dataSource?: Array<DataTypes>;
    /**分页配置 */
    pagination?: any;
    /**排序列 */
    sortColumn?: Column;
    /**真正显示在页面的数据 */
    showData?: Array<DataTypes>;
    /**选中当前行的rowkey ，单选*/
    selectRowKey?: StrOrNum;
    showDataAll?: Array<DataTypes>;
}
export declare type TableHeaderProps = TableProps & {
    headClassName?: string;
};
export declare type TableBodyProps = TableProps;
export interface searchType extends DataTypes {
    keySearch?: ObjType;
}
export {};
