import { Column, ObjType, TableProps, DataTypes, StrOrNum, searchType } from "./Types";
/**
 * 构建表格头 多列表头[[{}],[{}],[{}],[{}]...]的格式，方面在渲染列时使用数组遍历渲染，占多少列
 * @param columns
 */
export declare function convertToRows(columns: Array<Column>): Array<Array<Column>>;
/**
 * 将嵌套header组装成{...平级}方便赋值，获取的是所有叶子节点
 * @param columns
 */
export declare function getLeafColumns(columns: Array<Column>): Array<Column>;
/**
 * 构造列，构造成我们需要的数据结构（添加默认值和一些计算后的值），同时将index，radio，checkbox的列属性添加到columns里面
 * @param columns props里面的原始数据
 */
export declare function normalizeColumns(columns: Array<Column>): Array<Column>;
/**
 * 含有特殊字符的字符串需要转义
 * @param str
 * @returns {string}
 */
export declare function escapeStr(str: string): string;
/**
 * 从抽象语法树中取出值 类似于js的text()方法
 * @param tdValue
 * @returns {string}
 */
export declare function getTdValue(tdValue: any): string;
/**
 * 是否区分大小写
 * @param value
 */
export declare function isCaseFunc(value: string, keyword: string, isCase: boolean): boolean;
/**
 * 头部排序
 * @param sortData   需要排序的全部数据，如果为单页排序，则sortData为单页的数据，否则为全部要排序的数据
 * @param props
 */
export declare function sortOrderFunc(sortData: Array<DataTypes>, sortColumn: Column): Array<DataTypes>;
/**
 * 搜索
 * @param data
 * @param search
 * @param disCase
 */
export declare function searchFunc(data: Array<DataTypes>, props: TableProps): Array<searchType>;
/**
 * 页码改变 仅限前端分页,后台分页直接在使用时控制，将分页相关信息传进来即可
 * @param props
 * @param state
 * @param showData 页面上需要显示的所有数据
 */
export declare function dealPagination(props: TableProps, data: Array<DataTypes>, pagination: any): any;
/**
 * 设置key，table中每行数据必须有一个唯一的key值，避免在选择或者处理数据时出现点击这条数据选中其他数据的情况
 * @param row 当前行的数据
 * @param index 索引
 * @param props
 */
export declare function getKeyOfRow(row: ObjType, index: number, props: TableProps): StrOrNum;
/**
 * 数据组装
 * 主要是获取render函数执行的结果字段
 * 将data=[{},{},{}]格式改造成[{key:xxx,data:{}}]的格式，key：xxx作为每行数据的唯一值
 * 方便在搜索时直接搜索
 */
export declare function getKeyData(filteredData: Array<ObjType>, props: TableProps): Array<DataTypes>;
/**
 * 判断是否支持某个属性
 * @param attr attr:value
 */
export declare function isSupports(attr: string): boolean;
/**
 * 重写map
 */
export declare function map(arr: Array<any>, callback?: (item: any, index: number, array: any[]) => any): Array<any>;
