"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.convertToRows = convertToRows;
exports.dealPagination = dealPagination;
exports.escapeStr = escapeStr;
exports.getKeyData = getKeyData;
exports.getKeyOfRow = getKeyOfRow;
exports.getLeafColumns = getLeafColumns;
exports.getTdValue = getTdValue;
exports.isCaseFunc = isCaseFunc;
exports.isSupports = isSupports;
exports.map = map;
exports.normalizeColumns = normalizeColumns;
exports.searchFunc = searchFunc;
exports.sortOrderFunc = sortOrderFunc;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _util = require("../../libs/utils/util");

var _warning = _interopRequireDefault(require("../../libs/warning"));

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * 构建表格头 多列表头[[{}],[{}],[{}],[{}]...]的格式，方面在渲染列时使用数组遍历渲染，占多少列
 * @param columns
 */
function convertToRows(columns) {
  /**默认最大层级为1 */
  var maxLevel = 1;
  /**
   * 计算占多少列 colSpan占列
   * @param column 当前列
   * @param parent
   */

  var traverse = function traverse(column, parent) {
    /**如果有上一级，则当前的层级=父级的层级+1 */
    if (parent) {
      column.level = parent.level + 1;
      /**默认最大层级为1，如果有上一级，则最大层级小于了当前层级，就更新最大层级 为当前层级 */

      if (maxLevel < column.level) {
        maxLevel = column.level;
      }
    } else {
      /**没有上一级，默认层级为1 */
      column.level = 1;
    }
    /**如果有子列，最大层级加1，计算每一个子列的列宽，最后算出此列的列宽 */


    if (column.subColumns) {
      /**默认为0 */
      var colSpan = 0;
      column.subColumns.forEach(function (subColumn) {
        /**遍历，执行下面的cloumn.colSpan=1之后添加到本列上,如果有上一级，就把上一级传上去 */
        traverse(subColumn, column);
        colSpan += subColumn.colSpan;
      });
      /**将计算出来的列宽赋值到本列上 */

      column.colSpan = colSpan;
    } else {
      column.colSpan = 1;
    }
  };
  /**遍历计算有多少列 */


  columns.forEach(function (column) {
    traverse(column);
  });
  /**常见长度为maxLevel的空数组 */

  var rows = [];

  for (var i = 0; i < maxLevel; i++) {
    rows.push([]);
  }

  var allColumns = [];
  var queue = columns;
  /**allColumns是把所有的子节点提出来组成一个新的数组 */

  for (var _i = 0; queue[_i]; _i++) {
    allColumns.push(queue[_i]);

    if (queue[_i].subColumns) {
      queue.push.apply(queue, (0, _toConsumableArray2.default)(queue[_i].subColumns));
    }
  }

  allColumns.forEach(function (column) {
    if (!column.subColumns) {
      /**有子节点时，当前占的行数就是最大层级-当前列处在的行+1，比如最大层级为3，当前处于第二行，那么他的行数就是2，因为他没有子节点，所以会把最后剩下的行数占满 */
      column.rowSpan = maxLevel - column.level + 1;
    } else {
      /**如果有子节点的话，所占的行数就为1 */
      column.rowSpan = 1;
    }

    rows[column.level - 1].push(column);
  });
  return rows;
}
/**
 * 将嵌套header组装成{...平级}方便赋值，获取的是所有叶子节点
 * @param columns
 */


function getLeafColumns(columns) {
  var result = [];

  var loop = function loop(columns) {
    /**遍历columns，如果有子列，递归，继续遍历，没有就push到结果里 */
    columns.forEach(function (column) {
      if (column.subColumns) {
        loop(column.subColumns);
      } else {
        result.push(column);
      }
    });
  };

  loop(columns);
  return result;
}
/**头部对齐方式 ，如果有传头部对齐方式，则用头部的，否则就和body的对齐方式一致 */


var headerAlign = function headerAlign(column) {
  var align = null;

  if (column.headerAlign) {
    align = column.headerAlign.includes('is-') ? column.headerAlign : 'is-' + column.headerAlign;
  } else if (column.align) {
    align = column.align.includes('is-') ? column.align : 'is-' + column.align;
  }

  return align;
};
/**body的对齐方式 */


var bodyAlign = function bodyAlign(column) {
  var newAlign = null;

  if (column.align) {
    if (column.align.includes('is-')) {
      newAlign = column.align;
    } else {
      newAlign = 'is-' + column.align;
    }
  }

  return newAlign;
};
/**构造index，radio，checkbox */


var forced = function forced(column) {
  return {
    width: column.width || 60,
    minWidth: column.minWidth || 60,
    sortOrder: false,
    resizable: false
  };
};
/**
 * 构造列，构造成我们需要的数据结构（添加默认值和一些计算后的值），同时将index，radio，checkbox的列属性添加到columns里面
 * @param columns props里面的原始数据
 */


function normalizeColumns(columns) {
  /**返回columns构造之后的数据格式 */
  var loop = function loop(columns) {
    return map(columns, function (column) {
      var _column;
      /**如果当前列有孩子列，则将孩子当前列添加到新列中，并递归执行 */


      if (column.subColumns) {
        _column = Object.assign({}, column);
        _column.subColumns = loop(column.subColumns);
      } else {
        var width = column.width,
            minWidth = column.minWidth;
        /**宽度设置
         * 1、有宽度时，检测宽度是否有效 */

        if (width !== undefined) {
          if (isNaN(parseInt(width.toString(), 10))) {
            width = null;
          }
        }
        /**2、有最小宽度时，检测宽度是否有效，无效时，默认最小宽度为80 */


        if (minWidth !== undefined) {
          if (isNaN(parseInt(minWidth.toString(), 10))) {
            minWidth = 80;
          }
        } else {
          minWidth = 80;
        }

        return _column = Object.assign({
          /**默认值
           * 默认不可以拉伸列的宽度 */
          resizable: false,

          /**默认不排序 */
          sortOrder: false,

          /**默认靠左显示 */
          align: 'left',

          /**默认不可编辑 */
          editable: false,
          //title
          title: true
          /**传进来的值column */

        }, column, {
          fixed: column.fixed === true ? 'left' : column.fixed,

          /**计算后的值 */
          width: width,
          minWidth: minWidth,
          render: column.render,
          align: bodyAlign(column),
          headerAlign: headerAlign(column),

          /**默认超出显示...省略号 */
          headEllipsis: typeof column.headEllipsis === 'undefined' ? true : column.headEllipsis,
          ellipsis: typeof column.ellipsis === 'undefined' ? true : column.ellipsis
        }, column.type && forced(column));
      }

      return _column;
    });
  };

  return loop(columns);
}
/**
 * 含有特殊字符的字符串需要转义
 * @param str
 * @returns {string}
 */


function escapeStr(str) {
  var judgeReg = '*.?+$^[](){}|/';
  return map("".concat(str).split(''), function (item) {
    var have = judgeReg.split('').find(function (it) {
      return it === item;
    });

    if (have) {
      item = "\\".concat(item);
    }

    return item;
  }).join('');
}
/**
 * 从抽象语法树中取出值 类似于js的text()方法
 * @param tdValue
 * @returns {string}
 */


function getTdValue(tdValue) {
  var res = '';

  var loop = function loop(value) {
    //不能用render，当new一个type（class组件）时，没有执行生命周期，得到的值永远时最初始的值
    //colunms不能嵌套太深或者在里面写组件 如：组件里面有state或默认的值

    /**obj为抽象语法树 */
    var getValue = function getValue(obj) {
      /**有props说明是对象，否则可以直接赋值 */
      if (obj !== null && obj !== void 0 && obj.props) {
        /**如果还有子节点就再次执行loop方法 */
        if (obj.props.children) {
          loop(obj.props.children);
        }
      } else {
        res += obj || '';
      }
    };
    /**如果value为多个，则依次执行getValue方法，保证每个都执行到getValue */


    if (Array.isArray(value)) {
      value.forEach(function (item) {
        getValue(item);
      });
    } else {
      getValue(value);
    }
  };
  /**tdValue为抽象语法树 */


  loop(tdValue);
  return res;
}
/**
 * 是否区分大小写
 * @param value
 */


function isCaseFunc(value, keyword, isCase) {
  var result = false;
  value = value + "";
  /**如果isCase要区分大小写比较   ||   不区分大小写，value全部转换为小写比较 */

  if (isCase && value.match(keyword || '') != null || !isCase && value.toLowerCase().match((keyword || '').toLowerCase()) != null) {
    result = true;
  }

  return result;
}
/**
 * 头部排序
 * @param sortData   需要排序的全部数据，如果为单页排序，则sortData为单页的数据，否则为全部要排序的数据
 * @param props
 */


function sortOrderFunc(sortData, sortColumn) {
  /**获取sortColumn，在sortColumn里面对比排序，对于点击头部进行排序的情况，只可能对一列进行排序，复杂的排序，用自定义排序，如果有默认排序，会自执行一下点击头部事件，保证sortColumn有值 */
  var prop = sortColumn.prop;
  var sortOrder = sortColumn.sortOrder;
  /**如果该列没有排序，则直接返回 */

  if (!sortOrder) {
    return sortData;
  }

  sortOrder = sortOrder;
  /**没有排序回到初始状态 */

  if (!sortOrder.order) {
    return sortData;
  }
  /**如果存在自定义排序，则使用自定义排序，系统排序不生效 */


  return sortData.sort(function (a, b) {
    /**排序是先判断是根据字符串排序还是number排序，再判断是升序还是降序 */
    if (a.data[prop] === undefined || b.data[prop] === undefined || a.data[prop] == null || b.data[prop] == null) {
      (0, _warning.default)(false, 'Table', '该数据不建议为undefined或null');
      a.data[prop] = '';
      b.data[prop] = '';
    }

    sortOrder = sortOrder;

    if (sortOrder.type === 'number') {
      // warning(!Number(a.data[prop]),)
      if (sortOrder.order === 'ascending') {
        /**升序 */
        return a.data[prop] - b.data[prop];
      } else {
        /**降序 */
        return b.data[prop] - a.data[prop];
      }
    } else {
      /**自定义排序时， */
      if (sortOrder.customMethod) {
        (0, _warning.default)(false, 'table', '自定义排序时，如果有type为string，会优先以number排序，自定义排序不生效，要使用自定义排序，则不能将type设置为number，优先级为number>自定义>string');
        return sortOrder.customMethod(a.data, b.data, sortOrder.order);
      } else {
        /**默认字符串排序 */

        /**升序 */
        if (sortOrder.order === 'ascending') {
          return "".concat(a.data[prop]).localeCompare("".concat(b.data[prop]));
        } else {
          /**降序 */
          return "".concat(b.data[prop]).localeCompare("".concat(a.data[prop]));
        }
      }
    }
  });
}
/**
 * 搜索
 * @param data
 * @param search
 * @param disCase
 */


function searchFunc(data, props) {
  var search = props.search,
      columns = props.columns,
      keyWordClassName = props.keyWordClassName;
  var keyword = search.keyword;
  /**将字段的condition组装为colnums格式的数组对象 */

  var condition = [];
  /**没有填写搜素条件时为全部匹配筛选 有prop属性的colnum*/

  if (!search.condition || search.condition.length === 0) {
    columns.forEach(function (item) {
      if (item.prop) {
        condition.push(item);
      }
    });
  } else {
    /**有填写搜索字段 */
    columns.forEach(function (item) {
      if (search.condition.includes(item.prop)) {
        condition.push(item);
      }
    });
  }
  /**isCase区分大小写搜索，默认为false，不区分大小写 */


  var isCase = search.isCase || false;
  /**如果有搜索条件那么先转义 为了解决有些转义字符不能正确搜索 */

  keyword = "".concat(keyword).replace(/\\/g, '\\\\');
  keyword = escapeStr(keyword);
  var tableData = [];
  data.map(function (item) {
    /**将item.data真正数据重新命名 */
    var dataItem = (0, _util.deepClone)(item.data);

    var _dataItem = (0, _util.deepClone)(item.data);

    var _iterator = _createForOfIteratorHelper(columns),
        _step;

    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var field = _step.value;

        /**只针对有prop属性的列，没有prop一般为操作列或者选择框列，不需要进行特殊处理 */
        if (field.prop) {
          /**为了防止给下面的field.children重新赋值，造成修改到condition的结构，这里使用field的备份 */
          var _field = _objectSpread({}, field);
          /**构建_field.children,，如果有children就使用children，没有就是自己本身 */


          _field.children = _field.children || [_objectSpread({}, _field)];

          var _iterator3 = _createForOfIteratorHelper(_field.children),
              _step3;

          try {
            for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
              var fieldChild = _step3.value;
              var key = fieldChild.prop;
              /**遍历执行render函数，如果有render就执行，没有就直接使用值 */

              var tdValue = fieldChild.render ? fieldChild.render(_dataItem, _dataItem) : _dataItem[key];
              /**如果执行之后的结果为对象 通过递归得到最终结果*/
              // try {
              //     tdValue = JSXToText(tdValue);
              // } catch (error) {
              //     warning(false, 'Table', error.message);
              //     tdValue = getTdValue(tdValue);
              // }

              tdValue = getTdValue(tdValue);

              if (keyWordClassName) {
                tdValue = "".concat(tdValue).replace(keyword, "<span class=\"".concat(keyWordClassName || '', "\">").concat(keyword, "</span>"));
              }
              /**修改item的值 */


              dataItem[field.prop] = tdValue;
            }
          } catch (err) {
            _iterator3.e(err);
          } finally {
            _iterator3.f();
          }
        }
      }
      /**初始化result为false */

    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }

    var result = false;
    /**waiceng的作用是终止for循环 */

    var _iterator2 = _createForOfIteratorHelper(condition),
        _step2;

    try {
      waiceng: for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
        var _field2 = _step2.value;
        result = isCaseFunc(dataItem[_field2.prop], keyword, isCase);
        /**获取搜索结果，如果为true，就终止循环 */

        if (result) {
          break waiceng;
        }
      }
    } catch (err) {
      _iterator2.e(err);
    } finally {
      _iterator2.f();
    }

    if (result) {
      tableData.push(_objectSpread(_objectSpread({}, item), {}, {
        keySearch: dataItem
      }));
    }
  });
  /**获取到搜索之后的tableData数据 */

  return tableData;
}
/**
 * 页码改变 仅限前端分页,后台分页直接在使用时控制，将分页相关信息传进来即可
 * @param props
 * @param state
 * @param showData 页面上需要显示的所有数据
 */


function dealPagination(props, data, pagination) {
  /**newPagination  如果没有传分页相关的配置，则使用state里面默认的分页信息，有则在props里面进行覆盖*/

  /**frontPage是否为前端分页，默认为前端，如果是投胎分页，则传false */

  /**计算显示所有数据的总条数 */
  pagination = _objectSpread(_objectSpread({}, pagination), {}, {
    total: props.pagination.total || data.length
  });
  /**
   * 计算当前页的条数*当前页>总条数，
   * 则当前页码=总条数/每页显示条数 向上取
   * 这种一般处理当页面数据发生变化（删除）时，当前页码处于第十页，但是删除之后只有5页，就将当前页码指定到第五页
   * */

  if ((pagination.currentPage - 1) * pagination.pageSize >= pagination.total) {
    pagination.currentPage = Math.ceil(pagination.total / pagination.pageSize) || 1;
  }
  /**
   * 当前显示数据为从当前页数-1*每页显示条数到当前页数*每页显示条数
   * 如当前页数为2，则显示2-1 = 1*10，从下标10开始，2*10下标20结束
   */


  data = data.slice((pagination.currentPage - 1) * pagination.pageSize, pagination.currentPage * pagination.pageSize);
  /**设置显示数据和分页配置 */

  return {
    data: data,
    pagination: pagination
  };
}
/**
 * 设置key，table中每行数据必须有一个唯一的key值，避免在选择或者处理数据时出现点击这条数据选中其他数据的情况
 * @param row 当前行的数据
 * @param index 索引
 * @param props
 */


function getKeyOfRow(row, index, props) {
  /**如果props里面有rowKey方法，则执行rowKey方法，可传参数为当前行的数据，索引 */
  var rowKey = props.rowKey;
  var newKey;

  if (rowKey) {
    newKey = rowKey(row, index);
  } else {
    /**没有rowKey方法时，使用当前数据里面构造的key或者index */
    newKey = row.key || index;
  }

  return newKey;
}
/**
 * 数据组装
 * 主要是获取render函数执行的结果字段
 * 将data=[{},{},{}]格式改造成[{key:xxx,data:{}}]的格式，key：xxx作为每行数据的唯一值
 * 方便在搜索时直接搜索
 */


function getKeyData(filteredData, props) {
  /**最后得到的结果是[{key:xxx,data:{}}],没有render的结果 */
  return map(filteredData, function (item, index) {
    return {
      key: getKeyOfRow(item, index, props),
      data: item
    };
  });
}
/**
 * 判断是否支持某个属性
 * @param attr attr:value
 */


function isSupports(attr) {
  try {
    CSS.supports(attr);
    return true;
  } catch (error) {
    (0, _warning.default)(false, 'Table', "\u5F53\u524D\u6D4F\u89C8\u5668\u4E0D\u652F\u6301".concat(attr, "\u5C5E\u6027\uFF0C\u56FA\u5B9A\u5217\u4E0D\u751F\u6548\uFF0C\u53D8\u6210\u666E\u901A\u6EDA\u52A8"));
    return false;
  }
}
/**
 * 重写map
 */


function map(arr) {
  var callback = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : function () {
    return undefined;
  };
  var _arr = [];
  arr.forEach(function (item, index, array) {
    _arr.push(callback(item, index, array));
  });
  return _arr;
}