import * as React from 'react';
import TabPane from './TabPane';
declare const Types: ["default", "card", "border-card"];
declare type Type = typeof Types[number];
declare const PositionTypes: ["left", "top", "right", "bottom"];
declare type PositionType = typeof PositionTypes[number];
interface TabsProps {
    children?: any;
    type?: Type;
    activeName?: string;
    style?: React.CSSProperties;
    className?: string;
    tabPosition?: PositionType;
    addable?: boolean;
    tabNavStretch?: boolean;
    tabNavClassName?: string;
    tabNavInterval?: number;
    showTabNavBarByLabel?: boolean;
    onTabAdd?: () => void;
    onTabRemove?: (tab?: React.ReactNode, index?: number) => void;
    onTabClick?: (tab?: React.ReactElement<any, string | React.JSXElementConstructor<any>>, e?: React.MouseEvent<HTMLElement>) => void;
}
interface TabsState {
    children?: any;
    currentName?: string;
    barChange?: boolean;
    barStyle?: React.CSSProperties;
    navStyle?: React.CSSProperties;
    scrollable?: boolean;
    _prevProps?: TabsProps;
    scrollablePrev?: boolean;
    scrollableNext?: boolean;
    isAddStatus?: boolean;
}
export default class Tabs extends React.Component<TabsProps, TabsState> {
    static Pane: typeof TabPane;
    static defaultProps: {
        type: string;
        addable: boolean;
        tabPosition: string;
        tabNavStretch: boolean;
        tabNavInterval: number;
        showTabNavBarByLabel: boolean;
    };
    navScroll?: HTMLElement;
    nav?: HTMLElement;
    activeTab?: HTMLElement;
    /**
     *
     * @param props 构造函数
     */
    constructor(props: TabsProps);
    /**如果render为第一个，手动置为false */
    componentDidMount(): void;
    /**
     * 更新child和activename
     */
    static getDerivedStateFromProps(nextProps: TabsProps, prevState: TabsState): TabsState;
    /**更新 */
    componentDidUpdate(prevProps: TabsProps, prevState: TabsState): void;
    /** */
    scrollToActiveTab(): void;
    /**
     * tab切换
     * @param tab tabs实例
     * @param e
     */
    handleTabClick(tab: React.ReactElement<any, string | React.JSXElementConstructor<any>>, e?: React.MouseEvent<HTMLElement>): void;
    /**
     * 滑动条样式
     */
    calcBarStyle(): {
        barStyle: React.CSSProperties;
    };
    /**
     * tab动态添加
     */
    handleTabAdd(): void;
    /**
     * tab删除
     */
    handleTabRemove(tab: React.ReactNode, index: number, e: React.MouseEvent<HTMLElement>): void;
    /**更新控制滚动图标的显示隐藏 */
    updateAcrollable(): TabsState;
    /**
    * 滚动往前
    */
    scrollPrev(): void;
    /**滚动往后 */
    scrollNext(): void;
    /**获取滚动位置 */
    getCurrentScrollOffset(): number;
    /**设置滚动位置 */
    setOffset(value: number): void;
    /**
    * 渲染
    */
    render(): React.ReactNode;
}
export {};
