import * as React from 'react';
import { ForwardRef, ObjectType } from '../../libs/types';
import { InputBaseProps } from "../input/Input";
declare const InputResizeTypes: ["none", "both", "horizontal", "vertical"];
export declare type InputResize = typeof InputResizeTypes[number];
export interface TextAreaProps extends Omit<InputBaseProps, 'type' | 'prefix' | 'suffix'> {
    /**textarea自适应高度 **/
    autoSize?: boolean | {
        minRows?: number;
        maxRows?: number;
    };
    /**行**/
    rows?: number | string;
    /**规定文本区域的宽度（以平均字符宽度计）。默认值是 20。**/
    cols?: number | string;
    /**resize类型**/
    resize?: InputResize;
}
export interface TextAreaStates {
    fitSizeWidth?: any;
    fitSizePadding?: string;
    passwordType?: boolean;
    placeholderVisible?: boolean;
    focus?: boolean;
    height?: number;
    width?: number;
    valueLength?: number;
    style?: React.CSSProperties;
}
export interface TextAreaPropsWidthRef extends TextAreaProps, ForwardRef {
}
export default class TextArea extends React.Component<TextAreaPropsWidthRef, TextAreaStates> {
    protected inputRef: React.RefObject<any>;
    protected drag: {
        borderAndPaddingVerticalSize?: number;
        borderAndPaddingHorizontalSize?: number;
        width?: number;
        height?: number;
        startX?: number;
        startY?: number;
    };
    state: TextAreaStates;
    private textAreaWrapper;
    private limitText;
    /**
     * 构造函数
     * @param props
     */
    constructor(props: TextAreaPropsWidthRef);
    static defaultProps: {
        type: string;
        autoSize: boolean;
        rows: number;
        disabled: boolean;
        trim: boolean;
        resize: string;
        autoComplete: string;
        fitSize: boolean;
        size: string;
        bordered: boolean;
    };
    static contextType: React.Context<any>;
    /**
     *初次渲染
     */
    componentDidMount(): void;
    /**
     * 自动设置rows
     */
    autoSetRows(): void;
    /**
     * 组件更新后
     */
    componentDidUpdate(): void;
    /**
     * 处理点击事件
     * @param e
     */
    handleClick(e: React.MouseEvent<HTMLDivElement>): void;
    /**
     * 键盘落下事件
     * @param e
     */
    handleKeyDown(e: React.KeyboardEvent<HTMLInputElement> & React.KeyboardEvent<HTMLTextAreaElement>): void;
    /**
     * 值改变事件
     * @param e
     */
    handleChange(e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>): void;
    /**
     * 处理聚焦事件
     * @param e
     */
    handleFocus(e: React.FocusEvent<any>): void;
    /**
     * 处理失去焦点事件
     * @param e
     */
    handleBlur(e: React.FocusEvent<HTMLInputElement | HTMLTextAreaElement>): void;
    /**
     * 处理placeholder点击事件
     */
    handlePlaceHolderClick(): void;
    /**
     * 渲染placeholder
     * @param otherProps
     */
    renderPlaceholder(otherProps: React.InputHTMLAttributes<HTMLInputElement>): React.ReactElement;
    /**
     * 拖动结束
     * @param e
     */
    dragMove(e: MouseEvent): void;
    /**
     * 拖动结束
     */
    dragEnd(): void;
    /**
     * 处理鼠标落下事件
     */
    handleMouseDown(e: React.MouseEvent<HTMLOrSVGElement>): void;
    /**
     * 计算svg拖动的图标样式
     */
    getComputedDragStyle(): React.CSSProperties;
    /**
     * 渲染textarea
     * @param renderProps
     */
    renderRealTextArea(renderProps: ObjectType): React.ReactElement;
    /**
     * 渲染函数
     */
    render(): React.ReactNode;
}
export {};
