import * as React from 'react';
import { ObjectType } from "../../libs/types";
import { EnableTransitionProps } from "./EnableTransition";
interface TransitionProps {
    children?: React.ReactElement | false;
    name?: string;
    onBeforeEnter?: (transmit: ObjectType) => void;
    onEnter?: (dom: HTMLElement, transmit: ObjectType) => void;
    onEnterTo?: (dom: HTMLElement, transmit: ObjectType) => void;
    onAfterEnter?: (dom: HTMLElement, transmit: ObjectType) => void;
    onBeforeLeave?: (dom: HTMLElement, transmit: ObjectType) => void;
    onLeave?: (dom: HTMLElement, transmit: ObjectType) => void;
    onAfterLeave?: () => void;
    onLeaveTo?: (dom: HTMLElement, transmit: ObjectType) => void;
    /**可以通过 appear attribute 设置节点在初始渲染的过渡**/
    appear?: boolean;
    /**设置延迟时间**/
    duration?: number;
    /**控制是enter 还是leave
     * children 开始有 后面没有这种情况就可以不用设置
     * 这个可用于设置开始children有后面也有children 比如display变化
     *
     **/
    in?: boolean;
}
interface TransitionState {
    children?: React.ReactElement | false;
    in?: boolean;
    status?: Status;
    _prevProps?: TransitionProps;
    lifecycle?: Lifecycle;
}
declare enum Status {
    UNMOUNTED = "unmounted",
    ENTERING = "entering",
    ENTERED = "entered",
    LEAVED = "leaved",
    LEAVING = "leaving"
}
/***
 * 动画结束
 * @param el
 * @param duration
 * @param cb
 */
export declare function whenTransitionEnds(el: HTMLElement, duration: number, cb: () => void): void;
declare class Lifecycle {
    props: TransitionProps;
    private readonly transmit;
    /**
     * 构造函数
     * @param props
     */
    constructor(props?: TransitionProps);
    /**
     * 得到样式类
     */
    get transitionClass(): {
        enter?: string;
        enterActive?: string;
        enterTo?: string;
        leave?: string;
        leaveActive?: string;
        leaveTo?: string;
    };
    /**
     * beforeEnter
     */
    beforeEnter(): void;
    /***
     * enter
     * @param dom
     */
    enter(dom: HTMLElement): void;
    /**
     * entering
     * @param dom
     * @param cb
     */
    entering(dom: HTMLElement, cb?: (transmit: any) => void): void;
    /***
     * beforeLeave
     * @param dom
     */
    beforeLeave(dom?: HTMLElement): void;
    /**
     * leave
     * @param dom
     */
    leave(dom: HTMLElement): void;
    /**
     * leaving
     * @param dom
     * @param cb
     */
    leaving(dom: HTMLElement, cb?: () => void): void;
}
declare class Transition extends React.Component<TransitionProps, TransitionState> {
    static defaultProps: {
        appear: boolean;
        name: string;
        whenEnterDisplay: string;
    };
    private _isMounted;
    static StyleTransition: (props: TransitionProps) => React.ReactElement;
    static SwitchTransition: (props: TransitionProps) => React.ReactElement;
    static EnableTransition: (props: EnableTransitionProps) => React.ReactElement;
    /**
     * 构造函数
     * @param props
     */
    constructor(props: TransitionProps);
    /**
     * 当state或者props变化的时候
     * @param nextProps
     * @param prevState
     */
    static getDerivedStateFromProps(nextProps: TransitionProps, prevState: TransitionState): TransitionState;
    /**
     *
     */
    componentDidMount(): void;
    /**
     *
     */
    enterHook(): void;
    /**
     *
     */
    leaveHook(): void;
    /**
     * 安全的设置sate
     * @param state
     * @param callback
     */
    safeSetState(state: any, callback?: any): void;
    /**
     * 更新后
     * @param preProps
     */
    componentDidUpdate(preProps: TransitionProps): void;
    /**
     *
     */
    handleResetChildren(): void;
    /**
     *组件卸载后
     */
    componentWillUnmount(): void;
    /**
     * 渲染函数
     */
    render(): React.ReactNode;
}
export default Transition;
