import * as React from 'react';
import { Size } from "../../libs/types";
import { NodeProps } from "../tree/Node";
import { Slot } from "../input/Input";
export interface ItemOption {
    id?: string | number;
    label?: string;
    disabled?: boolean;
    isLeaf?: boolean;
    expanded?: boolean;
    checked?: boolean;
    children?: Array<ItemOption>;
}
export interface TreeSelectProps {
    className?: string;
    style?: React.CSSProperties;
    size?: Size;
    multiple?: boolean;
    checkAble?: boolean;
    /**数据源，其中的数据将会被渲染到左边一栏中**/
    value?: Array<ItemOption>;
    dataSource?: Array<ItemOption>;
    /**前缀自定义--位于边框内部**/
    prefix?: React.ReactNode | Slot | Array<Slot>;
    /**后缀自定义--位于边框内部**/
    suffix?: React.ReactNode | Slot | Array<Slot>;
    /**前缀自定义--位于边框外部**/
    prepend?: React.ReactNode;
    /**后缀自定义--位于边框外部**/
    append?: React.ReactNode;
    /**表单校验显示状态图标**/
    status?: Slot;
    /**指定的key**/
    nodeKey?: 'id' | 'label';
    /**默认展开所有的树节点**/
    defaultExpandAll?: boolean;
    /**选中节点其下的节点是否都选中**/
    nodeCheckedAndCheckedAllChildren?: boolean;
    /**默认展开复选框的树节点**/
    defaultExpandedKeys?: Array<string | number>;
    /**默认选中复选框的树节点**/
    defaultCheckedKeys?: Array<string | number>;
    /**(受控）展开指定的树节点**/
    expandedKeys?: Array<string | number>;
    /**(受控）选中指定的树节点**/
    checkedKeys?: Array<string | number>;
}
export interface TreeSelectState {
    _prevProps?: TreeSelectProps;
    value?: Array<{
        label: string;
        id: string | number;
    }>;
}
export default class TreeSelect extends React.Component<TreeSelectProps, TreeSelectState> {
    state: TreeSelectState;
    static defaultProps: TreeSelectProps;
    private el;
    /***
     *
     */
    handleChange(value: Array<ItemOption>): void;
    /***
     * 节点点击
     */
    handleNodeClick(e: React.MouseEvent<HTMLDivElement>, path: string, params: NodeProps): void;
    /**
     *
     * @param value
     * @param e
     */
    handleTagGroupChange(value: Array<{
        label: string;
        id: string | number;
    }>, e: React.MouseEvent<HTMLOrSVGElement>): void;
    /**
     *渲染函数
     */
    render(): React.ReactElement | string;
}
