import * as React from 'react';
import { NodeProps } from "./Node";
export interface ItemOption {
    id?: string | number;
    label?: string;
    disabled?: boolean;
    isLeaf?: boolean;
    expanded?: boolean;
    checked?: boolean;
    children?: Array<ItemOption>;
}
export interface _ItemOption extends ItemOption {
    path?: string;
    checked?: boolean;
    indeterminate?: boolean;
    children?: Array<_ItemOption>;
}
export interface TreeProps {
    className?: string;
    style?: React.CSSProperties;
    /**能否被选中**/
    checkAble?: boolean;
    /**支持点选多个节点（节点本身**/
    multiple?: boolean;
    /**是否显示点击后的状态**/
    showClickStatus?: boolean;
    /**左侧间距**/
    leftGap?: number;
    /**数据源，其中的数据将会被渲染到左边一栏中**/
    value?: Array<ItemOption>;
    /**指定的key**/
    nodeKey?: 'id' | 'label';
    /**默认展开所有的树节点**/
    defaultExpandAll?: boolean;
    /**选中节点其下的节点是否都选中**/
    nodeCheckedAndCheckedAllChildren?: boolean;
    /**默认展开复选框的树节点**/
    defaultExpandedKeys?: Array<string | number>;
    /**默认选中复选框的树节点**/
    defaultCheckedKeys?: Array<string | number>;
    /**(受控）展开指定的树节点**/
    expandedKeys?: Array<string | number>;
    /**(受控）选中指定的树节点**/
    checkedKeys?: Array<string | number>;
    onNodeClick?: (e: React.MouseEvent<HTMLDivElement>, path: string, params: NodeProps) => void;
    onChange?: (value: Array<ItemOption>, params: NodeProps, e: React.ChangeEvent<HTMLInputElement>) => void;
    onLoadData?: ({ key }: {
        key: string;
        children?: Array<ItemOption>;
        value?: Array<ItemOption>;
    }) => Promise<void>;
}
export interface TreeState {
    _prevProps?: TreeProps;
    value?: Array<_ItemOption>;
}
export default class Tree extends React.Component<TreeProps, TreeState> {
    state: TreeState;
    static defaultProps: TreeProps;
    /**
     * 构造函数
     * @param props
     */
    constructor(props: TreeProps);
    /**
     *
     * @param nextProps
     * @param prevState
     */
    static getDerivedStateFromProps(nextProps: TreeProps, prevState: TreeState): TreeState;
    /**
     *
     */
    static getAndSetDefaultChecked(props: TreeProps, expandedKeys?: Array<string | number>, checkedKeys?: Array<string | number>): Array<ItemOption>;
    /**
     * 动态加载数据
     * @param key
     * @param children
     * @param dataSource
     */
    private handleLoadData;
    /**
     *节点点击
     */
    private handleNodeClick;
    /**
     * defineProperty循环定义checked
     * @param baseDataSource
     */
    static loopDefinePropertyChecked(baseDataSource: _ItemOption[]): void;
    /**
     *
     * @param _dataSource
     * @param nodeCheckedAndCheckedAllChildren
     * @param checked
     */
    static loopSetProperty(_dataSource: _ItemOption, nodeCheckedAndCheckedAllChildren: boolean, checked: boolean): void;
    /**
     *节点选中
     */
    private handleNodeCheck;
    /**
     *渲染函数
     */
    render(): React.ReactElement | string;
}
