import * as React from 'react';
import { ProgressEvent } from './ajax';
import { ObjectType } from "../../libs/types";
import { ItemPreview, PreviewEventHandler, UploadError } from "./Upload";
export interface UploadProps extends PreviewEventHandler {
    children?: React.ReactNode;
    className?: string;
    style?: React.CSSProperties;
    fileName?: string;
    multiple?: boolean;
    /**重新去上传是否覆盖之前的**/
    showOnly?: boolean;
    extraData?: ObjectType;
    url?: string;
    type?: 'card' | 'list' | 'drag';
    control?: boolean;
    layout?: string;
    hint?: React.ReactNode;
    /**自定义Card添加上传图片处的内容 */
    customCard?: React.ReactNode;
    accept?: Array<string>;
    /**接受的文件类型是否忽略大小写 **/
    acceptIgnoreCase?: boolean;
    withCredentials?: boolean;
    previewData?: Array<ItemPreview> | false;
    headers?: ObjectType;
    onBeforeSubmit?: (value: FileList) => void;
    onSuccess?: (res: any) => void;
    onError?: (err: UploadError) => void;
    onProgress?: (e: ProgressEvent, files: Array<File>) => void;
    _maxWidth?: number;
    timeout?: number;
}
interface Blob {
    readonly size: number;
    readonly type: string;
    arrayBuffer(): Promise<ArrayBuffer>;
    slice(start?: number, end?: number, contentType?: string): Blob;
    stream(): ReadableStream;
    text(): Promise<string>;
}
interface File extends Blob {
    readonly lastModified: number;
    readonly name: string;
}
export interface FileList {
    readonly length: number;
    item(index: number): File | null;
    [index: number]: File;
}
export interface ItemFile {
    file: File;
    percent: number;
    key: number;
}
export interface UploadStates {
    files?: Array<ItemFile>;
    fileList?: Array<File>;
    value?: string;
}
export default class AjaxUpload extends React.PureComponent<UploadProps, UploadStates> {
    private fileInput;
    static defaultProps: UploadProps;
    state: UploadStates;
    private form;
    canUpload: boolean;
    /**
     *构造函数
     * @param props
     */
    constructor(props: UploadProps);
    /**
     * 界面更新后
     */
    componentDidUpdate(): void;
    /**
     * 处理包裹children的点击事件
     */
    handleClick(e: React.MouseEvent<HTMLElement>): void;
    /**
     *提交数据
     */
    handleSubmit(): void;
    /**
     * 校验错误格式
     * @param files
     */
    validateFile(files: FileList): Promise<boolean>;
    /**
     * 选中文件后的处理
     * @param e
     */
    handleFileChange(e: React.ChangeEvent<HTMLInputElement>): Promise<void>;
    /**
     * 拖拽选中文件后的回调
     * @param files
     */
    handleFile(files: FileList): Promise<void>;
    /**
     * 获取layout
     */
    getLayout(): {
        base: true;
        hint: React.ReactNode;
        preview: boolean;
    };
    /**
     * 提取公共部分
     * @param renderPreview
     * @param hint
     * @param type
     * @param children
     * @param multiple
     * @param fileName
     * @param className
     * @param style
     */
    uploadButton(renderPreview: React.ReactNode, hint: React.ReactNode, type: 'card' | 'list' | 'drag', children: React.ReactNode, multiple: boolean, fileName: string, className?: string, style?: React.CSSProperties, customCard?: React.ReactNode): React.ReactElement;
    /**
     * 渲染函数
     */
    render(): React.ReactNode;
}
export {};
