import * as React from 'react';
import { FileList } from './AjaxUpload';
import { ObjectType } from "../../libs/types";
import { ProgressEvent } from "./ajax";
export declare type Base64String = string;
export interface ItemPreview {
    url: URL | Base64String;
    name?: string;
    percent?: number;
}
export interface PreviewEventHandler {
    onReloaded?: (item: ItemPreview, index: number) => void;
    onDelete?: (item: ItemPreview, index: number) => void | boolean | Promise<boolean>;
}
export interface UploadError {
    detail?: any;
    msg: string;
    status?: number;
    method?: string;
    url?: string;
}
export interface UploadProps extends PreviewEventHandler {
    /**直接子类**/
    children?: React.ReactNode;
    /**类名称**/
    className?: string;
    /**样式**/
    style?: React.CSSProperties;
    /**文件名称**/
    fileName?: string;
    /**上传时的额外数据**/
    extraData?: ObjectType;
    /**上传时的url地址**/
    url?: string;
    /**文件预览的类型 card时必须要求服务端返回一个url字段才会预览 其中drag拖拽上传只支持 ie 10+**/
    type?: 'card' | 'list' | 'drag';
    /**布局 默认为 'base,hint,preview' type=card 不支持该属性**/
    layout?: string;
    /**自定义提示 type=card 不支持该属性**/
    hint?: React.ReactNode;
    /**自定义Card添加上传图片处的内容 */
    customCard?: React.ReactNode;
    /**接受的文件类型 如果有错误会在onError中提示**/
    accept?: Array<string>;
    /**接受的文件类型是否忽略大小写 **/
    acceptIgnoreCase?: boolean;
    /**上传时机 为true立即上传 false 不上传 该组件内部会判断上传时机**/
    control?: boolean;
    /**数据提交前的回调**/
    onBeforeSubmit?: (value: string | FileList) => void;
    /**成功返回的时的回调**/
    onSuccess?: (res: any) => void;
    /**失败的时的回调**/
    onError?: (err: UploadError) => void;
    /**预览的方式  数组代表前端预览   false 为默认值即不预览**/
    previewData?: Array<ItemPreview> | false;
    /**是否支持多选操作 ie10+支持**/
    multiple?: boolean;
    /**重新去上传是否覆盖之前的**/
    showOnly?: boolean;
    /**跨域请求是否提供凭据信息(cookie、HTTP认证及客户端SSL证明等) ie10+支持**/
    withCredentials?: boolean;
    /**自定义头部信息 ie10+支持**/
    headers?: ObjectType;
    /**进度条时的回调 ie10+支持**/
    onProgress?: (e: ProgressEvent, files: Array<File>) => void;
}
interface Snapshot {
    width: string;
    paddingLeft: string;
    paddingRight: string;
    borderLeftWidth: string;
    borderRightWidth: string;
}
export default class Upload extends React.PureComponent<UploadProps> {
    static defaultProps: {
        fileName: string;
        extraData: {};
        headers: {};
        type: string;
        withCredentials: boolean;
    };
    state: {
        maxWidth?: number;
    };
    private ref;
    private uploadRef;
    /**
     * 组件初始化
     */
    componentDidMount(): void;
    /**
     * 主动设置可上传，供外部调用
     */
    emitReUpload(canUpload: boolean): void;
    /**
     * 设置最大宽度
     */
    setMaxWidth(): void;
    /**
     *获取组件更新前一帧的数据
     */
    getSnapshotBeforeUpdate(): Snapshot;
    /**
     * 组件更新
     * @param prevProps
     * @param prevState
     * @param snapshot
     */
    componentDidUpdate(prevProps: Readonly<UploadProps>, prevState: Readonly<null>, snapshot?: Snapshot): void;
    /**
     * 渲染函数
     */
    render(): React.ReactNode;
}
export {};
